"""
Python module generated from Java source file org.yaml.snakeyaml.events.ScalarEvent

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml import DumperOptions
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.events import *
from typing import Any, Callable, Iterable, Tuple


class ScalarEvent(NodeEvent):
    """
    Marks a scalar value.
    """

    def __init__(self, anchor: str, tag: str, implicit: "ImplicitTuple", value: str, startMark: "Mark", endMark: "Mark", style: "DumperOptions.ScalarStyle"):
        ...


    def getTag(self) -> str:
        """
        Tag of this scalar.

        Returns
        - The tag of this scalar, or `null` if no explicit tag is available.
        """
        ...


    def getScalarStyle(self) -> "DumperOptions.ScalarStyle":
        """
        Style of the scalar.
        <dl>
        <dt>null</dt>
        <dd>Flow Style - Plain</dd>
        <dt>'\''</dt>
        <dd>Flow Style - Single-Quoted</dd>
        <dt>'"'</dt>
        <dd>Flow Style - Double-Quoted</dd>
        <dt>'|'</dt>
        <dd>Block Style - Literal</dd>
        <dt>'&gt;'</dt>
        <dd>Block Style - Folded</dd>
        </dl>

        Returns
        - Style of the scalar.

        See
        - <a href="http://yaml.org/spec/1.1/.id864487">Kind/Style Combinations</a>
        """
        ...


    def getValue(self) -> str:
        """
        String representation of the value.
        
        Without quotes and escaping.

        Returns
        - Value as Unicode string.
        """
        ...


    def getImplicit(self) -> "ImplicitTuple":
        ...


    def getEventId(self) -> "Event.ID":
        ...


    def isPlain(self) -> bool:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.emitter.Emitable

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from org.yaml.snakeyaml.emitter import *
from org.yaml.snakeyaml.events import Event
from typing import Any, Callable, Iterable, Tuple


class Emitable:
    """
    Define a way to serialize an event to output stream
    """

    def emit(self, event: "Event") -> None:
        """
        Serialise event to bytes

        Arguments
        - event: - the source

        Raises
        - IOException: if bytes bite
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.ItemSpawnEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.entity import Item
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class ItemSpawnEvent(EntitySpawnEvent):
    """
    Called when an item is spawned into a world
    """

    def __init__(self, spawnee: "Item", loc: "Location"):
        ...


    def __init__(self, spawnee: "Item"):
        ...


    def getEntity(self) -> "Item":
        ...



"""
Python module generated from Java source file com.google.common.annotations.J2ktIncompatible

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import *
from typing import Any, Callable, Iterable, Tuple


class J2ktIncompatible:
    """
    The presence of this annotation on an API indicates that the method may *not* be used with
    J2kt.

    Since
    - 32.0.0
    """





"""
Python module generated from Java source file java.nio.charset.CharsetDecoder

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.ref import WeakReference
from java.nio.charset import *
from java.nio.charset import CoderMalfunctionError
from java.util import Arrays
from typing import Any, Callable, Iterable, Tuple


class CharsetDecoder:

    def charset(self) -> "Charset":
        """
        Returns the charset that created this decoder.

        Returns
        - This decoder's charset
        """
        ...


    def replacement(self) -> str:
        """
        Returns this decoder's replacement value.

        Returns
        - This decoder's current replacement,
                 which is never `null` and is never empty
        """
        ...


    def replaceWith(self, newReplacement: str) -> "CharsetDecoder":
        """
        Changes this decoder's replacement value.
        
         This method invokes the .implReplaceWith implReplaceWith
        method, passing the new replacement, after checking that the new
        replacement is acceptable.  

        Arguments
        - newReplacement: The new replacement; must not be
                `null`, must have non-zero length,
        
                and must not be longer than the value returned by the
                .maxCharsPerByte() maxCharsPerByte method

        Returns
        - This decoder

        Raises
        - IllegalArgumentException: If the preconditions on the parameter do not hold
        """
        ...


    def malformedInputAction(self) -> "CodingErrorAction":
        """
        Returns this decoder's current action for malformed-input errors.

        Returns
        - The current malformed-input action, which is never `null`
        """
        ...


    def onMalformedInput(self, newAction: "CodingErrorAction") -> "CharsetDecoder":
        """
        Changes this decoder's action for malformed-input errors.
        
         This method invokes the .implOnMalformedInput
        implOnMalformedInput method, passing the new action.  

        Arguments
        - newAction: The new action; must not be `null`

        Returns
        - This decoder

        Raises
        - IllegalArgumentException: If the precondition on the parameter does not hold
        """
        ...


    def unmappableCharacterAction(self) -> "CodingErrorAction":
        """
        Returns this decoder's current action for unmappable-character errors.

        Returns
        - The current unmappable-character action, which is never
                `null`
        """
        ...


    def onUnmappableCharacter(self, newAction: "CodingErrorAction") -> "CharsetDecoder":
        """
        Changes this decoder's action for unmappable-character errors.
        
         This method invokes the .implOnUnmappableCharacter
        implOnUnmappableCharacter method, passing the new action.  

        Arguments
        - newAction: The new action; must not be `null`

        Returns
        - This decoder

        Raises
        - IllegalArgumentException: If the precondition on the parameter does not hold
        """
        ...


    def averageCharsPerByte(self) -> float:
        """
        Returns the average number of characters that will be produced for each
        byte of input.  This heuristic value may be used to estimate the size
        of the output buffer required for a given input sequence.

        Returns
        - The average number of characters produced
                 per byte of input
        """
        ...


    def maxCharsPerByte(self) -> float:
        """
        Returns the maximum number of characters that will be produced for each
        byte of input.  This value may be used to compute the worst-case size
        of the output buffer required for a given input sequence. This value
        accounts for any necessary content-independent prefix or suffix
        
        
        
        
        characters.

        Returns
        - The maximum number of characters that will be produced per
                 byte of input
        """
        ...


    def decode(self, in: "ByteBuffer", out: "CharBuffer", endOfInput: bool) -> "CoderResult":
        """
        Decodes as many bytes as possible from the given input buffer,
        writing the results to the given output buffer.
        
         The buffers are read from, and written to, starting at their current
        positions.  At most Buffer.remaining in.remaining() bytes
        will be read and at most Buffer.remaining out.remaining()
        characters will be written.  The buffers' positions will be advanced to
        reflect the bytes read and the characters written, but their marks and
        limits will not be modified.
        
         In addition to reading bytes from the input buffer and writing
        characters to the output buffer, this method returns a CoderResult
        object to describe its reason for termination:
        
        
        
          -  CoderResult.UNDERFLOW indicates that as much of the
          input buffer as possible has been decoded.  If there is no further
          input then the invoker can proceed to the next step of the
          <a href="#steps">decoding operation</a>.  Otherwise this method
          should be invoked again with further input.  
        
          -  CoderResult.OVERFLOW indicates that there is
          insufficient space in the output buffer to decode any more bytes.
          This method should be invoked again with an output buffer that has
          more Buffer.remaining remaining characters. This is
          typically done by draining any decoded characters from the output
          buffer.  
        
          -  A CoderResult.malformedForLength
          malformed-input result indicates that a malformed-input
          error has been detected.  The malformed bytes begin at the input
          buffer's (possibly incremented) position; the number of malformed
          bytes may be determined by invoking the result object's CoderResult.length() length method.  This case applies only if the
          .onMalformedInput malformed action of this decoder
          is CodingErrorAction.REPORT; otherwise the malformed input
          will be ignored or replaced, as requested.  
        
          -  An CoderResult.unmappableForLength
          unmappable-character result indicates that an
          unmappable-character error has been detected.  The bytes that
          decode the unmappable character begin at the input buffer's (possibly
          incremented) position; the number of such bytes may be determined
          by invoking the result object's CoderResult.length() length
          method.  This case applies only if the .onUnmappableCharacter
          unmappable action of this decoder is CodingErrorAction.REPORT; otherwise the unmappable character will be
          ignored or replaced, as requested.  
        
        
        
        In any case, if this method is to be reinvoked in the same decoding
        operation then care should be taken to preserve any bytes remaining
        in the input buffer so that they are available to the next invocation.
        
         The `endOfInput` parameter advises this method as to whether
        the invoker can provide further input beyond that contained in the given
        input buffer.  If there is a possibility of providing additional input
        then the invoker should pass `False` for this parameter; if there
        is no possibility of providing further input then the invoker should
        pass `True`.  It is not erroneous, and in fact it is quite
        common, to pass `False` in one invocation and later discover that
        no further input was actually available.  It is critical, however, that
        the final invocation of this method in a sequence of invocations always
        pass `True` so that any remaining undecoded input will be treated
        as being malformed.
        
         This method works by invoking the .decodeLoop decodeLoop
        method, interpreting its results, handling error conditions, and
        reinvoking it as necessary.  

        Arguments
        - in: The input byte buffer
        - out: The output character buffer
        - endOfInput: `True` if, and only if, the invoker can provide no
                additional input bytes beyond those in the given buffer

        Returns
        - A coder-result object describing the reason for termination

        Raises
        - IllegalStateException: If a decoding operation is already in progress and the previous
                 step was an invocation neither of the .reset reset
                 method, nor of this method with a value of `False` for
                 the `endOfInput` parameter, nor of this method with a
                 value of `True` for the `endOfInput` parameter
                 but a return value indicating an incomplete decoding operation
        - CoderMalfunctionError: If an invocation of the decodeLoop method threw
                 an unexpected exception
        """
        ...


    def flush(self, out: "CharBuffer") -> "CoderResult":
        """
        Flushes this decoder.
        
         Some decoders maintain internal state and may need to write some
        final characters to the output buffer once the overall input sequence has
        been read.
        
         Any additional output is written to the output buffer beginning at
        its current position.  At most Buffer.remaining out.remaining()
        characters will be written.  The buffer's position will be advanced
        appropriately, but its mark and limit will not be modified.
        
         If this method completes successfully then it returns CoderResult.UNDERFLOW.  If there is insufficient room in the output
        buffer then it returns CoderResult.OVERFLOW.  If this happens
        then this method must be invoked again, with an output buffer that has
        more room, in order to complete the current <a href="#steps">decoding
        operation</a>.
        
         If this decoder has already been flushed then invoking this method
        has no effect.
        
         This method invokes the .implFlush implFlush method to
        perform the actual flushing operation.  

        Arguments
        - out: The output character buffer

        Returns
        - A coder-result object, either CoderResult.UNDERFLOW or
                 CoderResult.OVERFLOW

        Raises
        - IllegalStateException: If the previous step of the current decoding operation was an
                 invocation neither of the .flush flush method nor of
                 the three-argument .decode(ByteBuffer,CharBuffer,boolean) decode method
                 with a value of `True` for the `endOfInput`
                 parameter
        """
        ...


    def reset(self) -> "CharsetDecoder":
        """
        Resets this decoder, clearing any internal state.
        
         This method resets charset-independent state and also invokes the
        .implReset() implReset method in order to perform any
        charset-specific reset actions.  

        Returns
        - This decoder
        """
        ...


    def decode(self, in: "ByteBuffer") -> "CharBuffer":
        """
        Convenience method that decodes the remaining content of a single input
        byte buffer into a newly-allocated character buffer.
        
         This method implements an entire <a href="#steps">decoding
        operation</a>; that is, it resets this decoder, then it decodes the
        bytes in the given byte buffer, and finally it flushes this
        decoder.  This method should therefore not be invoked if a decoding
        operation is already in progress.  

        Arguments
        - in: The input byte buffer

        Returns
        - A newly-allocated character buffer containing the result of the
                decoding operation.  The buffer's position will be zero and its
                limit will follow the last character written.

        Raises
        - IllegalStateException: If a decoding operation is already in progress
        - MalformedInputException: If the byte sequence starting at the input buffer's current
                 position is not legal for this charset and the current malformed-input action
                 is CodingErrorAction.REPORT
        - UnmappableCharacterException: If the byte sequence starting at the input buffer's current
                 position cannot be mapped to an equivalent character sequence and
                 the current unmappable-character action is CodingErrorAction.REPORT
        """
        ...


    def isAutoDetecting(self) -> bool:
        """
        Tells whether or not this decoder implements an auto-detecting charset.
        
         The default implementation of this method always returns
        `False`; it should be overridden by auto-detecting decoders to
        return `True`.  

        Returns
        - `True` if, and only if, this decoder implements an
                 auto-detecting charset
        """
        ...


    def isCharsetDetected(self) -> bool:
        """
        Tells whether or not this decoder has yet detected a
        charset&nbsp;&nbsp;*(optional operation)*.
        
         If this decoder implements an auto-detecting charset then at a
        single point during a decoding operation this method may start returning
        `True` to indicate that a specific charset has been detected in
        the input byte sequence.  Once this occurs, the .detectedCharset
        detectedCharset method may be invoked to retrieve the detected charset.
        
         That this method returns `False` does not imply that no bytes
        have yet been decoded.  Some auto-detecting decoders are capable of
        decoding some, or even all, of an input byte sequence without fixing on
        a particular charset.
        
         The default implementation of this method always throws an UnsupportedOperationException; it should be overridden by
        auto-detecting decoders to return `True` once the input charset
        has been determined.  

        Returns
        - `True` if, and only if, this decoder has detected a
                 specific charset

        Raises
        - UnsupportedOperationException: If this decoder does not implement an auto-detecting charset
        """
        ...


    def detectedCharset(self) -> "Charset":
        """
        Retrieves the charset that was detected by this
        decoder&nbsp;&nbsp;*(optional operation)*.
        
         If this decoder implements an auto-detecting charset then this
        method returns the actual charset once it has been detected.  After that
        point, this method returns the same value for the duration of the
        current decoding operation.  If not enough input bytes have yet been
        read to determine the actual charset then this method throws an IllegalStateException.
        
         The default implementation of this method always throws an UnsupportedOperationException; it should be overridden by
        auto-detecting decoders to return the appropriate value.  

        Returns
        - The charset detected by this auto-detecting decoder,
                 or `null` if the charset has not yet been determined

        Raises
        - IllegalStateException: If insufficient bytes have been read to determine a charset
        - UnsupportedOperationException: If this decoder does not implement an auto-detecting charset
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.constructor.ConstructorException

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.constructor import *
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.error import MarkedYAMLException
from typing import Any, Callable, Iterable, Tuple


class ConstructorException(MarkedYAMLException):
    """
    Exception during object construction
    """





"""
Python module generated from Java source file org.bukkit.block.data.type.Repeater

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Directional
from org.bukkit.block.data import Powerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Repeater(Directional, Powerable):
    """
    'delay' is the propagation delay of a repeater, i.e. how many ticks before it
    will be activated from a current change and propagate it to the next block.
    
    Delay may not be lower than .getMinimumDelay() or higher than
    .getMaximumDelay().
    
    'locked' denotes whether the repeater is in the locked state or not.
    
    A locked repeater will not change its output until it is unlocked. In game, a
    locked repeater is created by having a constant current perpendicularly
    entering the block.
    """

    def getDelay(self) -> int:
        """
        Gets the value of the 'delay' property.

        Returns
        - the 'delay' value
        """
        ...


    def setDelay(self, delay: int) -> None:
        """
        Sets the value of the 'delay' property.

        Arguments
        - delay: the new 'delay' value
        """
        ...


    def getMinimumDelay(self) -> int:
        """
        Gets the minimum allowed value of the 'delay' property.

        Returns
        - the minimum 'delay' value
        """
        ...


    def getMaximumDelay(self) -> int:
        """
        Gets the maximum allowed value of the 'delay' property.

        Returns
        - the maximum 'delay' value
        """
        ...


    def isLocked(self) -> bool:
        """
        Gets the value of the 'locked' property.

        Returns
        - the 'locked' value
        """
        ...


    def setLocked(self, locked: bool) -> None:
        """
        Sets the value of the 'locked' property.

        Arguments
        - locked: the new 'locked' value
        """
        ...



"""
Python module generated from Java source file com.google.common.io.Java8Compatibility

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from typing import Any, Callable, Iterable, Tuple


class Java8Compatibility:
    """
    Wrappers around Buffer methods that are covariantly overridden in Java 9+. See
    https://github.com/google/guava/issues/3990
    """





"""
Python module generated from Java source file org.bukkit.GameMode

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import Maps
from enum import Enum
from org.bukkit import *
from org.bukkit.entity import HumanEntity
from typing import Any, Callable, Iterable, Tuple


class GameMode(Enum):
    """
    Represents the various type of game modes that HumanEntitys may
    have
    """

    CREATIVE = (1)
    """
    Creative mode may fly, build instantly, become invulnerable and create
    free items.
    """
    SURVIVAL = (0)
    """
    Survival mode is the "normal" gameplay type, with no special features.
    """
    ADVENTURE = (2)
    """
    Adventure mode cannot break blocks without the correct tools.
    """
    SPECTATOR = (3)
    """
    Spectator mode cannot interact with the world in anyway and is
    invisible to normal players. This grants the player the
    ability to no-clip through the world.
    """


    def getValue(self) -> int:
        """
        Gets the mode value associated with this GameMode

        Returns
        - An integer value of this gamemode

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def getByValue(value: int) -> "GameMode":
        """
        Gets the GameMode represented by the specified value

        Arguments
        - value: Value to check

        Returns
        - Associative GameMode with the given value, or null if
            it doesn't exist

        Deprecated
        - Magic value
        """
        ...



"""
Python module generated from Java source file java.nio.charset.CharacterCodingException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.nio.charset import *
from typing import Any, Callable, Iterable, Tuple


class CharacterCodingException(IOException):

    def __init__(self):
        """
        Constructs an instance of this class.
        """
        ...



"""
Python module generated from Java source file java.util.jar.Attributes

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import ByteArrayOutputStream
from java.io import DataOutputStream
from java.io import IOException
from java.util import Objects
from java.util.jar import *
from jdk.internal.misc import CDS
from jdk.internal.vm.annotation import Stable
from sun.nio.cs import UTF_8
from sun.util.logging import PlatformLogger
from typing import Any, Callable, Iterable, Tuple


class Attributes(Map, Cloneable):
    """
    The Attributes class maps Manifest attribute names to associated string
    values. Valid attribute names are case-insensitive, are restricted to
    the ASCII characters in the set [0-9a-zA-Z_-], and cannot exceed 70
    characters in length. There must be a colon and a SPACE after the name;
    the combined length will not exceed 72 characters.
    Attribute values can contain any characters and
    will be UTF8-encoded when written to the output stream.  See the
    <a href="/../specs/jar/jar.html">JAR File Specification</a>
    for more information about valid attribute names and values.
    
    This map and its views have a predictable iteration order, namely the
    order that keys were inserted into the map, as with LinkedHashMap.

    Author(s)
    - David Connelly

    See
    - Manifest

    Since
    - 1.2
    """

    def __init__(self):
        """
        Constructs a new, empty Attributes object with default size.
        """
        ...


    def __init__(self, size: int):
        """
        Constructs a new, empty Attributes object with the specified
        initial size.

        Arguments
        - size: the initial number of attributes
        """
        ...


    def __init__(self, attr: "Attributes"):
        """
        Constructs a new Attributes object with the same attribute name-value
        mappings as in the specified Attributes.

        Arguments
        - attr: the specified Attributes
        """
        ...


    def get(self, name: "Object") -> "Object":
        """
        Returns the value of the specified attribute name, or null if the
        attribute name was not found.

        Arguments
        - name: the attribute name

        Returns
        - the value of the specified attribute name, or null if
                not found.
        """
        ...


    def getValue(self, name: str) -> str:
        """
        Returns the value of the specified attribute name, specified as
        a string, or null if the attribute was not found. The attribute
        name is case-insensitive.
        
        This method is defined as:
        ```
             return (String)get(new Attributes.Name((String)name));
        ```

        Arguments
        - name: the attribute name as a string

        Returns
        - the String value of the specified attribute name, or null if
                not found.

        Raises
        - IllegalArgumentException: if the attribute name is invalid
        """
        ...


    def getValue(self, name: "Name") -> str:
        """
        Returns the value of the specified Attributes.Name, or null if the
        attribute was not found.
        
        This method is defined as:
        ```
            return (String)get(name);
        ```

        Arguments
        - name: the Attributes.Name object

        Returns
        - the String value of the specified Attribute.Name, or null if
                not found.
        """
        ...


    def put(self, name: "Object", value: "Object") -> "Object":
        """
        Associates the specified value with the specified attribute name
        (key) in this Map. If the Map previously contained a mapping for
        the attribute name, the old value is replaced.

        Arguments
        - name: the attribute name
        - value: the attribute value

        Returns
        - the previous value of the attribute, or null if none

        Raises
        - ClassCastException: if the name is not a Attributes.Name
                   or the value is not a String
        """
        ...


    def putValue(self, name: str, value: str) -> str:
        """
        Associates the specified value with the specified attribute name,
        specified as a String. The attributes name is case-insensitive.
        If the Map previously contained a mapping for the attribute name,
        the old value is replaced.
        
        This method is defined as:
        ```
             return (String)put(new Attributes.Name(name), value);
        ```

        Arguments
        - name: the attribute name as a string
        - value: the attribute value

        Returns
        - the previous value of the attribute, or null if none

        Raises
        - IllegalArgumentException: if the attribute name is invalid
        """
        ...


    def remove(self, name: "Object") -> "Object":
        """
        Removes the attribute with the specified name (key) from this Map.
        Returns the previous attribute value, or null if none.

        Arguments
        - name: attribute name

        Returns
        - the previous value of the attribute, or null if none
        """
        ...


    def containsValue(self, value: "Object") -> bool:
        """
        Returns True if this Map maps one or more attribute names (keys)
        to the specified value.

        Arguments
        - value: the attribute value

        Returns
        - True if this Map maps one or more attribute names to
                the specified value
        """
        ...


    def containsKey(self, name: "Object") -> bool:
        """
        Returns True if this Map contains the specified attribute name (key).

        Arguments
        - name: the attribute name

        Returns
        - True if this Map contains the specified attribute name
        """
        ...


    def putAll(self, attr: dict[Any, Any]) -> None:
        """
        Copies all of the attribute name-value mappings from the specified
        Attributes to this Map. Duplicate mappings will be replaced.

        Arguments
        - attr: the Attributes to be stored in this map

        Raises
        - ClassCastException: if attr is not an Attributes
        """
        ...


    def clear(self) -> None:
        """
        Removes all attributes from this Map.
        """
        ...


    def size(self) -> int:
        """
        Returns the number of attributes in this Map.
        """
        ...


    def isEmpty(self) -> bool:
        """
        Returns True if this Map contains no attributes.
        """
        ...


    def keySet(self) -> set["Object"]:
        """
        Returns a Set view of the attribute names (keys) contained in this Map.
        """
        ...


    def values(self) -> Iterable["Object"]:
        """
        Returns a Collection view of the attribute values contained in this Map.
        """
        ...


    def entrySet(self) -> set["Map.Entry"["Object", "Object"]]:
        """
        Returns a Collection view of the attribute name-value mappings
        contained in this Map.
        """
        ...


    def equals(self, o: "Object") -> bool:
        """
        Compares the specified object to the underlying
        Attributes.map map for equality.
        Returns True if the given object is also a Map
        and the two maps represent the same mappings.

        Arguments
        - o: the Object to be compared

        Returns
        - True if the specified Object is equal to this Map
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code value for this Map.
        """
        ...


    def clone(self) -> "Object":
        """
        Returns a copy of the Attributes, implemented as follows:
        ```
            public Object clone() { return new Attributes(this); }
        ```
        Since the attribute names and values are themselves immutable,
        the Attributes returned can be safely modified without affecting
        the original.
        """
        ...


    class Name:
        """
        The Attributes.Name class represents an attribute name stored in
        this Map. Valid attribute names are case-insensitive, are restricted
        to the ASCII characters in the set [0-9a-zA-Z_-], and cannot exceed
        70 characters in length. Attribute values can contain any characters
        and will be UTF8-encoded when written to the output stream.  See the
        <a href="/../specs/jar/jar.html">JAR File Specification</a>
        for more information about valid attribute names and values.
        """

        MANIFEST_VERSION = None
        """
        `Name` object for `Manifest-Version`
        manifest attribute. This attribute indicates the version number
        of the manifest standard to which a JAR file's manifest conforms.

        See
        - <a href="/../specs/jar/jar.html.jar-manifest">
             Manifest and Signature Specification</a>
        """
        SIGNATURE_VERSION = None
        """
        `Name` object for `Signature-Version`
        manifest attribute used when signing JAR files.

        See
        - <a href="/../specs/jar/jar.html.jar-manifest">
             Manifest and Signature Specification</a>
        """
        CONTENT_TYPE = None
        """
        `Name` object for `Content-Type`
        manifest attribute.
        """
        CLASS_PATH = None
        """
        `Name` object for `Class-Path`
        manifest attribute.

        See
        - <a href="/../specs/jar/jar.html.class-path-attribute">
             JAR file specification</a>
        """
        MAIN_CLASS = None
        """
        `Name` object for `Main-Class` manifest
        attribute used for launching applications packaged in JAR files.
        The `Main-Class` attribute is used in conjunction
        with the `-jar` command-line option of the
        `java` application launcher.
        """
        SEALED = None
        """
        `Name` object for `Sealed` manifest attribute
        used for sealing.

        See
        - <a href="/../specs/jar/jar.html.package-sealing">
             Package Sealing</a>
        """
        EXTENSION_LIST = None
        """
        `Name` object for `Extension-List` manifest attribute
        used for the extension mechanism that is no longer supported.
        """
        EXTENSION_NAME = None
        """
        `Name` object for `Extension-Name` manifest attribute
        used for the extension mechanism that is no longer supported.
        """
        EXTENSION_INSTALLATION = None
        """
        `Name` object for `Extension-Installation` manifest attribute.

        Deprecated
        - Extension mechanism is no longer supported.
        """
        IMPLEMENTATION_TITLE = None
        """
        `Name` object for `Implementation-Title`
        manifest attribute used for package versioning.
        """
        IMPLEMENTATION_VERSION = None
        """
        `Name` object for `Implementation-Version`
        manifest attribute used for package versioning.
        """
        IMPLEMENTATION_VENDOR = None
        """
        `Name` object for `Implementation-Vendor`
        manifest attribute used for package versioning.
        """
        IMPLEMENTATION_VENDOR_ID = None
        """
        `Name` object for `Implementation-Vendor-Id`
        manifest attribute.

        Deprecated
        - Extension mechanism is no longer supported.
        """
        IMPLEMENTATION_URL = None
        """
        `Name` object for `Implementation-URL`
        manifest attribute.

        Deprecated
        - Extension mechanism is no longer supported.
        """
        SPECIFICATION_TITLE = None
        """
        `Name` object for `Specification-Title`
        manifest attribute used for package versioning.
        """
        SPECIFICATION_VERSION = None
        """
        `Name` object for `Specification-Version`
        manifest attribute used for package versioning.
        """
        SPECIFICATION_VENDOR = None
        """
        `Name` object for `Specification-Vendor`
        manifest attribute used for package versioning.
        """
        MULTI_RELEASE = None
        """
        `Name` object for `Multi-Release`
        manifest attribute that indicates this is a multi-release JAR file.

        Since
        - 9
        """


        def __init__(self, name: str):
            """
            Constructs a new attribute name using the given string name.

            Arguments
            - name: the attribute string name

            Raises
            - IllegalArgumentException: if the attribute name was
                       invalid
            - NullPointerException: if the attribute name was null
            """
            ...


        def equals(self, o: "Object") -> bool:
            """
            Compares this attribute name to another for equality.

            Arguments
            - o: the object to compare

            Returns
            - True if this attribute name is equal to the
                    specified attribute object
            """
            ...


        def hashCode(self) -> int:
            """
            Computes the hash value for this attribute name.
            """
            ...


        def toString(self) -> str:
            """
            Returns the attribute name as a String.
            """
            ...



"""
Python module generated from Java source file org.bukkit.inventory.view.builder.InventoryViewBuilder

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import HumanEntity
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory.view.builder import *
from typing import Any, Callable, Iterable, Tuple


class InventoryViewBuilder:
    """
    Generic Builder for InventoryView's with no special attributes or parameters
    
    Type `<V>`: the type of InventoryView created from this builder
    """

    def copy(self) -> "InventoryViewBuilder"["V"]:
        """
        Makes a copy of this builder

        Returns
        - a copy of this builder
        """
        ...


    def title(self, title: str) -> "InventoryViewBuilder"["V"]:
        """
        Sets the title of the builder

        Arguments
        - title: the title

        Returns
        - this builder
        """
        ...


    def build(self, player: "HumanEntity") -> "V":
        """
        Builds this builder into a InventoryView

        Arguments
        - player: the player to assign to the view

        Returns
        - the created InventoryView
        """
        ...



"""
Python module generated from Java source file org.bukkit.conversations.ConversationContext

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.conversations import *
from org.bukkit.plugin import Plugin
from typing import Any, Callable, Iterable, Tuple


class ConversationContext:
    """
    A ConversationContext provides continuity between nodes in the prompt graph
    by giving the developer access to the subject of the conversation and a
    generic map for storing values that are shared between all Prompt
    invocations.
    """

    def __init__(self, plugin: "Plugin", forWhom: "Conversable", initialSessionData: dict["Object", "Object"]):
        """
        Arguments
        - plugin: The owning plugin.
        - forWhom: The subject of the conversation.
        - initialSessionData: Any initial values to put in the sessionData
            map.
        """
        ...


    def getPlugin(self) -> "Plugin":
        """
        Gets the plugin that owns this conversation.

        Returns
        - The owning plugin.
        """
        ...


    def getForWhom(self) -> "Conversable":
        """
        Gets the subject of the conversation.

        Returns
        - The subject of the conversation.
        """
        ...


    def getAllSessionData(self) -> dict["Object", "Object"]:
        """
        Gets the underlying sessionData map.
        
        May be directly modified to manipulate session data.

        Returns
        - The full sessionData map.
        """
        ...


    def getSessionData(self, key: "Object") -> "Object":
        """
        Gets session data shared between all Prompt invocations. Use
        this as a way to pass data through each Prompt as the conversation
        develops.

        Arguments
        - key: The session data key.

        Returns
        - The requested session data.
        """
        ...


    def setSessionData(self, key: "Object", value: "Object") -> None:
        """
        Sets session data shared between all Prompt invocations. Use
        this as a way to pass data through each prompt as the conversation
        develops.

        Arguments
        - key: The session data key.
        - value: The session data value.
        """
        ...



"""
Python module generated from Java source file org.joml.sampling.BestCandidateSampling

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.joml import Random
from org.joml import Vector2f
from org.joml import Vector3f
from org.joml.sampling import *
from typing import Any, Callable, Iterable, Tuple


class BestCandidateSampling:
    """
    Creates samples using the "Best Candidate" algorithm.

    Author(s)
    - Kai Burjack
    """

    class Sphere:
        """
        Generates Best Candidate samples on a unit sphere.
        
        References:
        
        - <a href="https://arxiv.org/ftp/cs/papers/0701/0701164.pdf">Indexing the Sphere with the Hierarchical Triangular Mesh</a>
        - <a href="http://math.stackexchange.com/questions/1244512/point-in-a-spherical-triangle-test">Point in a spherical triangle test</a>

    Author(s)
        - Kai Burjack
        """

        def __init__(self):
            """
            Create a new instance of Sphere to configure and generate 'best candidate' sample positions on the unit sphere.
            """
            ...


        def generate(self, xyzs: list[float]) -> "Sphere":
            """
            Generate 'best candidate' sample positions and store the coordinates of all generated samples into the given `xyzs` float array.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - xyzs: will hold the x, y and z coordinates of all samples in the order `XYZXYZXYZ...`.
                       This array must have a length of at least `numSamples`

            Returns
            - this
            """
            ...


        def generate(self, xyzs: "FloatBuffer") -> "Sphere":
            """
            Generate 'best candidate' sample positions and store the coordinates of all generated samples into the given `xyzs` FloatBuffer.
            
            The samples will be written starting at the current position of the FloatBuffer. The position of the FloatBuffer will not be modified.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - xyzs: will hold the x, y and z coordinates of all samples in the order `XYZXYZXYZ...`.
                       This FloatBuffer must have at least `numSamples` remaining elements.
                       The position of the buffer will not be modified by this method

            Returns
            - this
            """
            ...


        def seed(self, seed: int) -> "Sphere":
            """
            Set the seed to initialize the pseudo-random number generator with.

            Arguments
            - seed: the seed value

            Returns
            - this
            """
            ...


        def numSamples(self, numSamples: int) -> "Sphere":
            """
            Set the number of samples to generate.

            Arguments
            - numSamples: the number of samples

            Returns
            - this
            """
            ...


        def numCandidates(self, numCandidates: int) -> "Sphere":
            """
            Set the number of candidates to try for each generated sample.

            Arguments
            - numCandidates: the number of candidates to try

            Returns
            - this
            """
            ...


        def onHemisphere(self, onHemisphere: bool) -> "Sphere":
            """
            Set whether to generate samples on a hemisphere around the `+Z` axis.
            
            The default is `False`, which will generate samples on the whole unit sphere.

            Arguments
            - onHemisphere: whether to generate samples on the hemisphere

            Returns
            - this
            """
            ...


        def generate(self, callback: "Callback3d") -> "Sphere":
            """
            Generate 'best candidate' sample call the given `callback` for each generated sample.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - callback: will be called with the coordinates of each generated sample position

            Returns
            - this
            """
            ...


    class Disk:
        """
        Generates Best Candidate samples on a unit disk.

    Author(s)
        - Kai Burjack
        """

        def __init__(self):
            """
            Create a new instance of Disk to configure and generate 'best candidate' sample positions on the unit disk.
            """
            ...


        def seed(self, seed: int) -> "Disk":
            """
            Set the seed to initialize the pseudo-random number generator with.

            Arguments
            - seed: the seed value

            Returns
            - this
            """
            ...


        def numSamples(self, numSamples: int) -> "Disk":
            """
            Set the number of samples to generate.

            Arguments
            - numSamples: the number of samples

            Returns
            - this
            """
            ...


        def numCandidates(self, numCandidates: int) -> "Disk":
            """
            Set the number of candidates to try for each generated sample.

            Arguments
            - numCandidates: the number of candidates to try

            Returns
            - this
            """
            ...


        def generate(self, xys: list[float]) -> "Disk":
            """
            Generate 'best candidate' sample positions and store the coordinates of all generated samples into the given `xys` float array.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - xys: will hold the x and y coordinates of all samples in the order `XYXYXY...`.
                       This array must have a length of at least `numSamples`

            Returns
            - this
            """
            ...


        def generate(self, xys: "FloatBuffer") -> "Disk":
            """
            Generate 'best candidate' sample positions and store the coordinates of all generated samples into the given `xys` FloatBuffer.
            
            The samples will be written starting at the current position of the FloatBuffer. The position of the FloatBuffer will not be modified.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - xys: will hold the x and y coordinates of all samples in the order `XYXYXY...`. This FloatBuffer must have at least `numSamples` remaining elements. The
                       position of the buffer will not be modified by this method

            Returns
            - this
            """
            ...


        def generate(self, callback: "Callback2d") -> "Disk":
            """
            Generate 'best candidate' sample positions and call the given `callback` for each generated sample.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - callback: will be called with the coordinates of each generated sample position

            Returns
            - this
            """
            ...


    class Quad:
        """
        Generates Best Candidate samples on a unit quad.

    Author(s)
        - Kai Burjack
        """

        def __init__(self):
            """
            Create a new instance of Quad to configure and generate 'best candidate' sample positions on the unit quad.
            """
            ...


        def seed(self, seed: int) -> "Quad":
            """
            Set the seed to initialize the pseudo-random number generator with.

            Arguments
            - seed: the seed value

            Returns
            - this
            """
            ...


        def numSamples(self, numSamples: int) -> "Quad":
            """
            Set the number of samples to generate.

            Arguments
            - numSamples: the number of samples

            Returns
            - this
            """
            ...


        def numCandidates(self, numCandidates: int) -> "Quad":
            """
            Set the number of candidates to try for each generated sample.

            Arguments
            - numCandidates: the number of candidates to try

            Returns
            - this
            """
            ...


        def generate(self, xyzs: list[float]) -> "Quad":
            """
            Generate 'best candidate' sample positions and store the coordinates of all generated samples into the given `xyzs` float array.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - xyzs: will hold the x, y and z coordinates of all samples in the order `XYZXYZXYZ...`.
                       This array must have a length of at least `numSamples`

            Returns
            - this
            """
            ...


        def generate(self, xys: "FloatBuffer") -> "Quad":
            """
            Generate 'best candidate' sample positions and store the coordinates of all generated samples into the given `xys` FloatBuffer.
            
            The samples will be written starting at the current position of the FloatBuffer. The position of the FloatBuffer will not be modified.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - xys: will hold the x and y coordinates of all samples in the order `XYXYXY...`. This FloatBuffer must have at least `numSamples` remaining elements. The position of
                       the buffer will not be modified by this method

            Returns
            - this
            """
            ...


        def generate(self, callback: "Callback2d") -> "Quad":
            """
            Generate 'best candidate' sample positions and call the given `callback` for each generated sample.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - callback: will be called with the coordinates of each generated sample position

            Returns
            - this
            """
            ...


    class Cube:
        """
        Generates Best Candidate samples inside a unit cube.

    Author(s)
        - Kai Burjack
        """

        def __init__(self):
            """
            Create a new instance of Cube to configure and generate 'best candidate' sample positions
            on the unit cube with each sample tried `numCandidates` number of times, and call the 
            given `callback` for each sample generate.
            """
            ...


        def seed(self, seed: int) -> "Cube":
            """
            Set the seed to initialize the pseudo-random number generator with.

            Arguments
            - seed: the seed value

            Returns
            - this
            """
            ...


        def numSamples(self, numSamples: int) -> "Cube":
            """
            Set the number of samples to generate.

            Arguments
            - numSamples: the number of samples

            Returns
            - this
            """
            ...


        def numCandidates(self, numCandidates: int) -> "Cube":
            """
            Set the number of candidates to try for each generated sample.

            Arguments
            - numCandidates: the number of candidates to try

            Returns
            - this
            """
            ...


        def generate(self, xyzs: list[float]) -> "Cube":
            """
            Generate 'best candidate' sample positions and store the coordinates of all generated samples into the given `xyzs` float array.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - xyzs: will hold the x, y and z coordinates of all samples in the order `XYZXYZXYZ...`.
                       This array must have a length of at least `numSamples`

            Returns
            - this
            """
            ...


        def generate(self, xyzs: "FloatBuffer") -> "Cube":
            """
            Generate 'best candidate' sample positions and store the coordinates of all generated samples into the given `xyzs` FloatBuffer.
            
            The samples will be written starting at the current position of the FloatBuffer. The position of the FloatBuffer will not be modified.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - xyzs: will hold the x, y and z coordinates of all samples in the order `XYZXYZXYZ...`.
                       This FloatBuffer must have at least `numSamples` remaining elements.
                       The position of the buffer will not be modified by this method

            Returns
            - this
            """
            ...


        def generate(self, callback: "Callback3d") -> "Cube":
            """
            Generate 'best candidate' sample positions and call the given `callback` for each generated sample.
            
            *This method performs heap allocations, so should be used sparingly.*

            Arguments
            - callback: will be called with the coordinates of each generated sample position

            Returns
            - this
            """
            ...



"""
Python module generated from Java source file java.io.Writer

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class Writer(Appendable, Closeable, Flushable):

    @staticmethod
    def nullWriter() -> "Writer":
        """
        Returns a new `Writer` which discards all characters.  The
        returned stream is initially open.  The stream is closed by calling
        the `close()` method.  Subsequent calls to `close()` have
        no effect.
        
         While the stream is open, the `append(char)`, `append(CharSequence)`, `append(CharSequence, int, int)`,
        `flush()`, `write(int)`, `write(char[])`, and
        `write(char[], int, int)` methods do nothing. After the stream
        has been closed, these methods all throw `IOException`.
        
         The .lock object used to synchronize operations on the
        returned `Writer` is not specified.

        Returns
        - a `Writer` which discards all characters

        Since
        - 11
        """
        ...


    def write(self, c: int) -> None:
        """
        Writes a single character.  The character to be written is contained in
        the 16 low-order bits of the given integer value; the 16 high-order bits
        are ignored.
        
         Subclasses that intend to support efficient single-character output
        should override this method.

        Arguments
        - c: int specifying a character to be written

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def write(self, cbuf: list[str]) -> None:
        """
        Writes an array of characters.

        Arguments
        - cbuf: Array of characters to be written

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def write(self, cbuf: list[str], off: int, len: int) -> None:
        """
        Writes a portion of an array of characters.

        Arguments
        - cbuf: Array of characters
        - off: Offset from which to start writing characters
        - len: Number of characters to write

        Raises
        - IndexOutOfBoundsException: Implementations should throw this exception
                 if `off` is negative, or `len` is negative,
                 or `off + len` is negative or greater than the length
                 of the given array
        - IOException: If an I/O error occurs
        """
        ...


    def write(self, str: str) -> None:
        """
        Writes a string.

        Arguments
        - str: String to be written

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def write(self, str: str, off: int, len: int) -> None:
        """
        Writes a portion of a string.

        Arguments
        - str: A String
        - off: Offset from which to start writing characters
        - len: Number of characters to write

        Raises
        - IndexOutOfBoundsException: Implementations should throw this exception
                 if `off` is negative, or `len` is negative,
                 or `off + len` is negative or greater than the length
                 of the given string
        - IOException: If an I/O error occurs

        Unknown Tags
        - The implementation in this class throws an
        `IndexOutOfBoundsException` for the indicated conditions;
        overriding methods may choose to do otherwise.
        """
        ...


    def append(self, csq: "CharSequence") -> "Writer":
        """
        Appends the specified character sequence to this writer.
        
         An invocation of this method of the form `out.append(csq)`
        behaves in exactly the same way as the invocation
        
        ```
            out.write(csq.toString()) ```
        
         Depending on the specification of `toString` for the
        character sequence `csq`, the entire sequence may not be
        appended. For instance, invoking the `toString` method of a
        character buffer will return a subsequence whose content depends upon
        the buffer's position and limit.

        Arguments
        - csq: The character sequence to append.  If `csq` is
                `null`, then the four characters `"null"` are
                appended to this writer.

        Returns
        - This writer

        Raises
        - IOException: If an I/O error occurs

        Since
        - 1.5
        """
        ...


    def append(self, csq: "CharSequence", start: int, end: int) -> "Writer":
        """
        Appends a subsequence of the specified character sequence to this writer.
        `Appendable`.
        
         An invocation of this method of the form
        `out.append(csq, start, end)` when `csq`
        is not `null` behaves in exactly the
        same way as the invocation
        
        ````out.write(csq.subSequence(start, end).toString())````

        Arguments
        - csq: The character sequence from which a subsequence will be
                appended.  If `csq` is `null`, then characters
                will be appended as if `csq` contained the four
                characters `"null"`.
        - start: The index of the first character in the subsequence
        - end: The index of the character following the last character in the
                subsequence

        Returns
        - This writer

        Raises
        - IndexOutOfBoundsException: If `start` or `end` are negative, `start`
                 is greater than `end`, or `end` is greater than
                 `csq.length()`
        - IOException: If an I/O error occurs

        Since
        - 1.5
        """
        ...


    def append(self, c: str) -> "Writer":
        """
        Appends the specified character to this writer.
        
         An invocation of this method of the form `out.append(c)`
        behaves in exactly the same way as the invocation
        
        ```
            out.write(c) ```

        Arguments
        - c: The 16-bit character to append

        Returns
        - This writer

        Raises
        - IOException: If an I/O error occurs

        Since
        - 1.5
        """
        ...


    def flush(self) -> None:
        """
        Flushes the stream.  If the stream has saved any characters from the
        various write() methods in a buffer, write them immediately to their
        intended destination.  Then, if that destination is another character or
        byte stream, flush it.  Thus one flush() invocation will flush all the
        buffers in a chain of Writers and OutputStreams.
        
         If the intended destination of this stream is an abstraction provided
        by the underlying operating system, for example a file, then flushing the
        stream guarantees only that bytes previously written to the stream are
        passed to the operating system for writing; it does not guarantee that
        they are actually written to a physical device such as a disk drive.

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def close(self) -> None:
        """
        Closes the stream, flushing it first. Once the stream has been closed,
        further write() or flush() invocations will cause an IOException to be
        thrown. Closing a previously closed stream has no effect.

        Raises
        - IOException: If an I/O error occurs
        """
        ...



"""
Python module generated from Java source file org.bukkit.material.Vine

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Arrays
from java.util import EnumSet
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Vine(MaterialData):
    """
    Represents a vine

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def __init__(self, data: int):
        """
        Arguments
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def __init__(self, *faces: Tuple["BlockFace", ...]):
        ...


    def __init__(self, faces: "EnumSet"["BlockFace"]):
        ...


    def isOnFace(self, face: "BlockFace") -> bool:
        """
        Check if the vine is attached to the specified face of an adjacent
        block. You can check two faces at once by passing e.g. BlockFace.NORTH_EAST.

        Arguments
        - face: The face to check.

        Returns
        - Whether it is attached to that face.
        """
        ...


    def putOnFace(self, face: "BlockFace") -> None:
        """
        Attach the vine to the specified face of an adjacent block.

        Arguments
        - face: The face to attach.
        """
        ...


    def removeFromFace(self, face: "BlockFace") -> None:
        """
        Detach the vine from the specified face of an adjacent block.

        Arguments
        - face: The face to detach.
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "Vine":
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingSortedSetMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.util import Comparator
from java.util import SortedSet
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingSortedSetMultimap(ForwardingSetMultimap, SortedSetMultimap):
    """
    A sorted set multimap which forwards all its method calls to another sorted set multimap.
    Subclasses should override one or more methods to modify the behavior of the backing multimap as
    desired per the <a href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingSortedSetMultimap`.

    Author(s)
    - Kurt Alfred Kluever

    Since
    - 3.0
    """

    def get(self, key: "K") -> "SortedSet"["V"]:
        ...


    def removeAll(self, key: "Object") -> "SortedSet"["V"]:
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> "SortedSet"["V"]:
        ...


    def valueComparator(self) -> "Comparator"["V"]:
        ...



"""
Python module generated from Java source file java.net.NetworkInterface

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.net import *
from java.util import Arrays
from java.util import Enumeration
from java.util import NoSuchElementException
from java.util import Spliterator
from java.util.stream import Stream
from java.util.stream import StreamSupport
from typing import Any, Callable, Iterable, Tuple


class NetworkInterface:
    """
    This class represents a Network Interface made up of a name,
    and a list of IP addresses assigned to this interface.
    It is used to identify the local interface on which a multicast group
    is joined.
    
    Interfaces are normally known by names such as "le0".

    Since
    - 1.4
    """

    def getName(self) -> str:
        """
        Get the name of this network interface.

        Returns
        - the name of this network interface
        """
        ...


    def getInetAddresses(self) -> "Enumeration"["InetAddress"]:
        """
        Get an Enumeration with all or a subset of the InetAddresses bound to
        this network interface.
        
        If there is a security manager, its `checkConnect`
        method is called for each InetAddress. Only InetAddresses where
        the `checkConnect` doesn't throw a SecurityException
        will be returned in the Enumeration. However, if the caller has the
        NetPermission("getNetworkInformation") permission, then all
        InetAddresses are returned.

        Returns
        - an Enumeration object with all or a subset of the InetAddresses
        bound to this network interface

        See
        - .inetAddresses()
        """
        ...


    def inetAddresses(self) -> "Stream"["InetAddress"]:
        """
        Get a Stream of all or a subset of the InetAddresses bound to this
        network interface.
        
        If there is a security manager, its `checkConnect`
        method is called for each InetAddress. Only InetAddresses where
        the `checkConnect` doesn't throw a SecurityException will be
        returned in the Stream. However, if the caller has the
        NetPermission("getNetworkInformation") permission, then all
        InetAddresses are returned.

        Returns
        - a Stream object with all or a subset of the InetAddresses
        bound to this network interface

        Since
        - 9
        """
        ...


    def getInterfaceAddresses(self) -> "java.util.List"["InterfaceAddress"]:
        """
        Get a List of all or a subset of the `InterfaceAddresses`
        of this network interface.
        
        If there is a security manager, its `checkConnect`
        method is called with the InetAddress for each InterfaceAddress.
        Only InterfaceAddresses where the `checkConnect` doesn't throw
        a SecurityException will be returned in the List.

        Returns
        - a `List` object with all or a subset of the
                InterfaceAddress of this network interface

        Since
        - 1.6
        """
        ...


    def getSubInterfaces(self) -> "Enumeration"["NetworkInterface"]:
        """
        Get an Enumeration with all the subinterfaces (also known as virtual
        interfaces) attached to this network interface.
        
        For instance eth0:1 will be a subinterface to eth0.

        Returns
        - an Enumeration object with all of the subinterfaces
        of this network interface

        See
        - .subInterfaces()

        Since
        - 1.6
        """
        ...


    def subInterfaces(self) -> "Stream"["NetworkInterface"]:
        """
        Get a Stream of all subinterfaces (also known as virtual
        interfaces) attached to this network interface.

        Returns
        - a Stream object with all of the subinterfaces
        of this network interface

        Since
        - 9
        """
        ...


    def getParent(self) -> "NetworkInterface":
        """
        Returns the parent NetworkInterface of this interface if this is
        a subinterface, or `null` if it is a physical
        (non virtual) interface or has no parent.

        Returns
        - The `NetworkInterface` this interface is attached to.

        Since
        - 1.6
        """
        ...


    def getIndex(self) -> int:
        """
        Returns the index of this network interface. The index is an integer greater
        or equal to zero, or `-1` for unknown. This is a system specific value
        and interfaces with the same name can have different indexes on different
        machines.

        Returns
        - the index of this network interface or `-1` if the index is
                unknown

        See
        - .getByIndex(int)

        Since
        - 1.7
        """
        ...


    def getDisplayName(self) -> str:
        """
        Get the display name of this network interface.
        A display name is a human readable String describing the network
        device.

        Returns
        - a non-empty string representing the display name of this network
                interface, or null if no display name is available.
        """
        ...


    @staticmethod
    def getByName(name: str) -> "NetworkInterface":
        """
        Searches for the network interface with the specified name.

        Arguments
        - name: The name of the network interface.

        Returns
        - A `NetworkInterface` with the specified name,
                 or `null` if there is no network interface
                 with the specified name.

        Raises
        - SocketException: If an I/O error occurs.
        - NullPointerException: If the specified name is `null`.
        """
        ...


    @staticmethod
    def getByIndex(index: int) -> "NetworkInterface":
        """
        Get a network interface given its index.

        Arguments
        - index: an integer, the index of the interface

        Returns
        - the NetworkInterface obtained from its index, or `null` if
                there is no interface with such an index on the system

        Raises
        - SocketException: if an I/O error occurs.
        - IllegalArgumentException: if index has a negative value

        See
        - .getIndex()

        Since
        - 1.7
        """
        ...


    @staticmethod
    def getByInetAddress(addr: "InetAddress") -> "NetworkInterface":
        """
        Convenience method to search for a network interface that
        has the specified Internet Protocol (IP) address bound to
        it.
        
        If the specified IP address is bound to multiple network
        interfaces it is not defined which network interface is
        returned.

        Arguments
        - addr: The `InetAddress` to search with.

        Returns
        - A `NetworkInterface`
                 or `null` if there is no network interface
                 with the specified IP address.

        Raises
        - SocketException: If an I/O error occurs.
        - NullPointerException: If the specified address is `null`.
        """
        ...


    @staticmethod
    def getNetworkInterfaces() -> "Enumeration"["NetworkInterface"]:
        """
        Returns an `Enumeration` of all the interfaces on this machine. The
        `Enumeration` contains at least one element, possibly representing
        a loopback interface that only supports communication between entities on
        this machine.

        Returns
        - an Enumeration of NetworkInterfaces found on this machine

        Raises
        - SocketException: if an I/O error occurs,
                    or if the platform does not have at least one configured
                    network interface.

        See
        - .networkInterfaces()

        Unknown Tags
        - this method can be used in combination with
        .getInetAddresses() to obtain all IP addresses for this node
        """
        ...


    @staticmethod
    def networkInterfaces() -> "Stream"["NetworkInterface"]:
        """
        Returns a `Stream` of all the interfaces on this machine.  The
        `Stream` contains at least one interface, possibly representing a
        loopback interface that only supports communication between entities on
        this machine.

        Returns
        - a Stream of NetworkInterfaces found on this machine

        Raises
        - SocketException: if an I/O error occurs,
                    or if the platform does not have at least one configured
                    network interface.

        Since
        - 9

        Unknown Tags
        - this method can be used in combination with
        .inetAddresses()} to obtain a stream of all IP addresses for
        this node, for example:
        ``` `Stream<InetAddress> addrs = NetworkInterface.networkInterfaces()
            .flatMap(NetworkInterface::inetAddresses);````
        """
        ...


    def isUp(self) -> bool:
        ...


    def isLoopback(self) -> bool:
        ...


    def isPointToPoint(self) -> bool:
        ...


    def supportsMulticast(self) -> bool:
        ...


    def getHardwareAddress(self) -> list[int]:
        """
        Returns the hardware address (usually MAC) of the interface if it
        has one and if it can be accessed given the current privileges.
        If a security manager is set, then the caller must have
        the permission NetPermission("getNetworkInformation").

        Returns
        - a byte array containing the address, or `null` if
                 the address doesn't exist, is not accessible or a security
                 manager is set and the caller does not have the permission
                 NetPermission("getNetworkInformation")

        Raises
        - SocketException: if an I/O error occurs.

        Since
        - 1.6
        """
        ...


    def getMTU(self) -> int:
        """
        Returns the Maximum Transmission Unit (MTU) of this interface.

        Returns
        - the value of the MTU for that interface.

        Raises
        - SocketException: if an I/O error occurs.

        Since
        - 1.6
        """
        ...


    def isVirtual(self) -> bool:
        """
        Returns whether this interface is a virtual interface (also called
        subinterface).
        Virtual interfaces are, on some systems, interfaces created as a child
        of a physical interface and given different settings (like address or
        MTU). Usually the name of the interface will the name of the parent
        followed by a colon (:) and a number identifying the child since there
        can be several virtual interfaces attached to a single physical
        interface.

        Returns
        - `True` if this interface is a virtual interface.

        Since
        - 1.6
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares this object against the specified object.
        The result is `True` if and only if the argument is
        not `null` and it represents the same NetworkInterface
        as this object.
        
        Two instances of `NetworkInterface` represent the same
        NetworkInterface if both the name and the set of `InetAddress`es
        bound to the interfaces are equal.

        Arguments
        - obj: the object to compare against.

        Returns
        - `True` if the objects are the same;
                 `False` otherwise.

        See
        - java.net.InetAddress.getAddress()

        Unknown Tags
        - two `NetworkInterface` objects referring to the same
        underlying interface may not compare equal if the addresses
        of the underlying interface are being dynamically updated by
        the system.
        """
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.BigDripleaf

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class BigDripleaf(Dripleaf):
    """
    'tilt' indicates how far the leaf is tilted.
    """

    def getTilt(self) -> "Tilt":
        """
        Gets the value of the 'tilt' property.

        Returns
        - the 'tilt' value
        """
        ...


    def setTilt(self, tilt: "Tilt") -> None:
        """
        Sets the value of the 'tilt' property.

        Arguments
        - tilt: the new 'tilt' value
        """
        ...


    class Tilt(Enum):
        """
        The tilt of a leaf.
        """

        NONE = 0
        """
        No tilt.
        """
        UNSTABLE = 1
        """
        Unstable tilt.
        """
        PARTIAL = 2
        """
        Partial tilt.
        """
        FULL = 3
        """
        Pinball.
        """



"""
Python module generated from Java source file org.bukkit.packs.DataPackManager

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit import World
from org.bukkit.block import BlockType
from org.bukkit.entity import EntityType
from org.bukkit.inventory import ItemType
from org.bukkit.packs import *
from typing import Any, Callable, Iterable, Tuple


class DataPackManager:
    """
    Manager of data packs.
    """

    def getDataPacks(self) -> Iterable["DataPack"]:
        """
        Return all the available DataPacks on the server.

        Returns
        - a Collection of DataPack
        """
        ...


    def getDataPack(self, dataPackKey: "NamespacedKey") -> "DataPack":
        """
        Gets a DataPack by its key.

        Arguments
        - dataPackKey: the key of the DataPack

        Returns
        - the DataPack or null if it does not exist
        """
        ...


    def getEnabledDataPacks(self, world: "World") -> Iterable["DataPack"]:
        """
        Return all the enabled DataPack in the World.

        Arguments
        - world: the world to search

        Returns
        - a Collection of DataPack
        """
        ...


    def getDisabledDataPacks(self, world: "World") -> Iterable["DataPack"]:
        """
        Return all the disabled DataPack in the World.

        Arguments
        - world: the world to search

        Returns
        - a Collection of DataPack
        """
        ...


    def isEnabledByFeature(self, material: "Material", world: "World") -> bool:
        """
        Gets if the Material is enabled for use by the features in World.

        Arguments
        - material: Material to check (needs to be an Material.isItem() or Material.isBlock())
        - world: World to check

        Returns
        - `True` if the Item/Block related to the material is enabled
        """
        ...


    def isEnabledByFeature(self, itemType: "ItemType", world: "World") -> bool:
        """
        Gets if the ItemType is enabled for use by the features in World.

        Arguments
        - itemType: ItemType to check
        - world: World to check

        Returns
        - `True` if the ItemType is enabled

        Unknown Tags
        - this method is not ready for public usage yet
        """
        ...


    def isEnabledByFeature(self, blockType: "BlockType", world: "World") -> bool:
        """
        Gets if the BlockType is enabled for use by the features in World.

        Arguments
        - blockType: BlockType to check
        - world: World to check

        Returns
        - `True` if the BlockType is enabled

        Unknown Tags
        - this method is not ready for public usage yet
        """
        ...


    def isEnabledByFeature(self, entityType: "EntityType", world: "World") -> bool:
        """
        Gets if the EntityType is enabled for use by the Features in World.

        Arguments
        - entityType: EntityType to check
        - world: World to check

        Returns
        - `True` if the type of entity is enabled
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableListMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import RetainedWith
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.util import Comparator
from java.util.function import Function
from java.util.stream import Collector
from java.util.stream import Stream
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableListMultimap(ImmutableMultimap, ListMultimap):
    """
    A ListMultimap whose contents will never change, with many other important properties
    detailed at ImmutableCollection.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/ImmutableCollectionsExplained">immutable collections</a>.

    Author(s)
    - Jared Levy

    Since
    - 2.0
    """

    @staticmethod
    def toImmutableListMultimap(keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"]) -> "Collector"["T", Any, "ImmutableListMultimap"["K", "V"]]:
        """
        Returns a Collector that accumulates elements into an `ImmutableListMultimap`
        whose keys and values are the result of applying the provided mapping functions to the input
        elements.
        
        For streams with defined encounter order (as defined in the Ordering section of the java.util.stream Javadoc), that order is preserved, but entries are <a
        href="ImmutableMultimap.html#iteration">grouped by key</a>.
        
        Example:
        
        ````static final Multimap<Character, String> FIRST_LETTER_MULTIMAP =
            Stream.of("banana", "apple", "carrot", "asparagus", "cherry")
                .collect(toImmutableListMultimap(str -> str.charAt(0), str -> str.substring(1)));
        
        // is equivalent to
        
        static final Multimap<Character, String> FIRST_LETTER_MULTIMAP =
            new ImmutableListMultimap.Builder<Character, String>()
                .put('b', "anana")
                .putAll('a', "pple", "sparagus")
                .putAll('c', "arrot", "herry")
                .build();````

        Since
        - 21.0
        """
        ...


    @staticmethod
    def flatteningToImmutableListMultimap(keyFunction: "Function"["T", "K"], valuesFunction: "Function"["T", "Stream"["V"]]) -> "Collector"["T", Any, "ImmutableListMultimap"["K", "V"]]:
        """
        Returns a `Collector` accumulating entries into an `ImmutableListMultimap`. Each
        input element is mapped to a key and a stream of values, each of which are put into the
        resulting `Multimap`, in the encounter order of the stream and the encounter order of the
        streams of values.
        
        Example:
        
        ````static final ImmutableListMultimap<Character, Character> FIRST_LETTER_MULTIMAP =
            Stream.of("banana", "apple", "carrot", "asparagus", "cherry")
                .collect(
                    flatteningToImmutableListMultimap(
                         str -> str.charAt(0),
                         str -> str.substring(1).chars().mapToObj(c -> (char) c));
        
        // is equivalent to
        
        static final ImmutableListMultimap<Character, Character> FIRST_LETTER_MULTIMAP =
            ImmutableListMultimap.<Character, Character>builder()
                .putAll('b', Arrays.asList('a', 'n', 'a', 'n', 'a'))
                .putAll('a', Arrays.asList('p', 'p', 'l', 'e'))
                .putAll('c', Arrays.asList('a', 'r', 'r', 'o', 't'))
                .putAll('a', Arrays.asList('s', 'p', 'a', 'r', 'a', 'g', 'u', 's'))
                .putAll('c', Arrays.asList('h', 'e', 'r', 'r', 'y'))
                .build();`
        }```

        Since
        - 21.0
        """
        ...


    @staticmethod
    def of() -> "ImmutableListMultimap"["K", "V"]:
        ...


    @staticmethod
    def of(k1: "K", v1: "V") -> "ImmutableListMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing a single entry.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V") -> "ImmutableListMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the given entries, in order.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V") -> "ImmutableListMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the given entries, in order.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V") -> "ImmutableListMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the given entries, in order.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V") -> "ImmutableListMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the given entries, in order.
        """
        ...


    @staticmethod
    def builder() -> "Builder"["K", "V"]:
        """
        Returns a new builder. The generated builder is equivalent to the builder created by the Builder constructor.
        """
        ...


    @staticmethod
    def builderWithExpectedKeys(expectedKeys: int) -> "Builder"["K", "V"]:
        """
        Returns a new builder with a hint for how many distinct keys are expected to be added. The
        generated builder is equivalent to that returned by .builder, but may perform better if
        `expectedKeys` is a good estimate.

        Raises
        - IllegalArgumentException: if `expectedKeys` is negative

        Since
        - 33.3.0
        """
        ...


    @staticmethod
    def copyOf(multimap: "Multimap"["K", "V"]) -> "ImmutableListMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the same mappings as `multimap`. The generated
        multimap's key and value orderings correspond to the iteration ordering of the `multimap.asMap()` view.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.

        Raises
        - NullPointerException: if any key or value in `multimap` is null
        """
        ...


    @staticmethod
    def copyOf(entries: Iterable["Entry"["K", "V"]]) -> "ImmutableListMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the specified entries. The returned multimap iterates
        over keys in the order they were first encountered in the input, and the values for each key
        are iterated in the order they were encountered.

        Raises
        - NullPointerException: if any key, value, or entry is null

        Since
        - 19.0
        """
        ...


    def get(self, key: "K") -> "ImmutableList"["V"]:
        """
        Returns an immutable list of the values for the given key. If no mappings in the multimap have
        the provided key, an empty immutable list is returned. The values are in the same order as the
        parameters used to build this multimap.
        """
        ...


    def inverse(self) -> "ImmutableListMultimap"["V", "K"]:
        """
        
        
        Because an inverse of a list multimap can contain multiple pairs with the same key and
        value, this method returns an `ImmutableListMultimap` rather than the `ImmutableMultimap` specified in the `ImmutableMultimap` class.

        Since
        - 11.0
        """
        ...


    def removeAll(self, key: "Object") -> "ImmutableList"["V"]:
        """
        Guaranteed to throw an exception and leave the multimap unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> "ImmutableList"["V"]:
        """
        Guaranteed to throw an exception and leave the multimap unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    class Builder(Builder):
        """
        A builder for creating immutable `ListMultimap` instances, especially `public
        static final` multimaps ("constant multimaps"). Example:
        
        ````static final Multimap<String, Integer> STRING_TO_INTEGER_MULTIMAP =
            new ImmutableListMultimap.Builder<String, Integer>()
                .put("one", 1)
                .putAll("several", 1, 2, 3)
                .putAll("many", 1, 2, 3, 4, 5)
                .build();````
        
        Builder instances can be reused; it is safe to call .build multiple times to build
        multiple multimaps in series. Each multimap contains the key-value mappings in the previously
        created multimaps.

        Since
        - 2.0
        """

        def __init__(self):
            """
            Creates a new builder. The returned builder is equivalent to the builder generated by ImmutableListMultimap.builder.
            """
            ...


        def expectedValuesPerKey(self, expectedValuesPerKey: int) -> "Builder"["K", "V"]:
            """
            Since
            - 33.3.0
            """
            ...


        def put(self, key: "K", value: "V") -> "Builder"["K", "V"]:
            ...


        def put(self, entry: "Entry"["K", "V"]) -> "Builder"["K", "V"]:
            """
            Since
            - 11.0
            """
            ...


        def putAll(self, entries: Iterable["Entry"["K", "V"]]) -> "Builder"["K", "V"]:
            """
            Since
            - 19.0
            """
            ...


        def putAll(self, key: "K", values: Iterable["V"]) -> "Builder"["K", "V"]:
            ...


        def putAll(self, key: "K", *values: Tuple["V", ...]) -> "Builder"["K", "V"]:
            ...


        def putAll(self, multimap: "Multimap"["K", "V"]) -> "Builder"["K", "V"]:
            ...


        def orderKeysBy(self, keyComparator: "Comparator"["K"]) -> "Builder"["K", "V"]:
            """
            Since
            - 8.0
            """
            ...


        def orderValuesBy(self, valueComparator: "Comparator"["V"]) -> "Builder"["K", "V"]:
            """
            Since
            - 8.0
            """
            ...


        def build(self) -> "ImmutableListMultimap"["K", "V"]:
            """
            Returns a newly-created immutable list multimap.
            """
            ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.trim.ArmorTrim

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.util import Objects
from org.bukkit.inventory.meta import ArmorMeta
from org.bukkit.inventory.meta.trim import *
from typing import Any, Callable, Iterable, Tuple


class ArmorTrim:
    """
    Represents an armor trim that may be applied to an item.

    See
    - ArmorMeta.setTrim(ArmorTrim)
    """

    def __init__(self, material: "TrimMaterial", pattern: "TrimPattern"):
        """
        Create a new ArmorTrim given a TrimMaterial and
        TrimPattern.

        Arguments
        - material: the material
        - pattern: the pattern
        """
        ...


    def getMaterial(self) -> "TrimMaterial":
        """
        Get the TrimMaterial for this armor trim.

        Returns
        - the material
        """
        ...


    def getPattern(self) -> "TrimPattern":
        """
        Get the TrimPattern for this armor trim.

        Returns
        - the pattern
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.scoreboard.Criterias

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.scoreboard import *
from typing import Any, Callable, Iterable, Tuple


class Criterias:
    """
    Criteria names which trigger an objective to be modified by actions in-game

    Deprecated
    - use the constants declared in Criteria instead
    """

    HEALTH = "health"
    PLAYER_KILLS = "playerKillCount"
    TOTAL_KILLS = "totalKillCount"
    DEATHS = "deathCount"



"""
Python module generated from Java source file org.bukkit.advancement.AdvancementDisplayType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import ChatColor
from org.bukkit.advancement import *
from typing import Any, Callable, Iterable, Tuple


class AdvancementDisplayType(Enum):
    """
    Advancements are displayed in different ways depending on their display type.
    
    This enum contains information about these types and how they are
    represented.
    """

    TASK = (ChatColor.GREEN)
    """
    Task or normal icons have a square icon frame.
    """
    CHALLENGE = (ChatColor.DARK_PURPLE)
    """
    Challenge icons have a stylised icon frame.
    """
    GOAL = (ChatColor.GREEN)
    """
    Goal icons have a rounded icon frame.
    """


    def getColor(self) -> "ChatColor":
        """
        The chat color used by Minecraft for this advancement.

        Returns
        - The chat color used by this advancement type.
        """
        ...



"""
Python module generated from Java source file org.bukkit.loot.Lootable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.loot import *
from typing import Any, Callable, Iterable, Tuple


class Lootable:
    """
    Represents a org.bukkit.block.Container or a
    org.bukkit.entity.Mob that can have a loot table.
    
    Container loot will only generate upon opening, and only when the container
    is *first* opened.
    
    Entities will only generate loot upon death.
    """

    def setLootTable(self, table: "LootTable") -> None:
        """
        Set the loot table for a container or entity.
        
        To remove a loot table use null.

        Arguments
        - table: the Loot Table this org.bukkit.block.Container or
        org.bukkit.entity.Mob will have.
        """
        ...


    def getLootTable(self) -> "LootTable":
        """
        Gets the Loot Table attached to this block or entity.
        
        
        If an block/entity does not have a loot table, this will return null, NOT
        an empty loot table.

        Returns
        - the Loot Table attached to this block or entity.
        """
        ...


    def setSeed(self, seed: int) -> None:
        """
        Set the seed used when this Loot Table generates loot.

        Arguments
        - seed: the seed to used to generate loot. Default is 0.
        """
        ...


    def getSeed(self) -> int:
        """
        Get the Loot Table's seed.
        
        The seed is used when generating loot.

        Returns
        - the seed
        """
        ...



"""
Python module generated from Java source file org.bukkit.StructureType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.base import Strings
from com.google.common.collect import ImmutableMap
from java.util import Objects
from org.bukkit import *
from org.bukkit.map import MapCursor
from typing import Any, Callable, Iterable, Tuple


class StructureType(Keyed):

    MINESHAFT = register(StructureType("mineshaft", MapCursor.Type.RED_X))
    """
    Mineshafts are underground structures which consist of branching mining
    tunnels with wooden supports and broken rails.
    
    They are the only place where cave spider spawners and minecarts with
    chests can be found naturally.
    """
    VILLAGE = register(StructureType("village", MapCursor.Type.MANSION))
    """
    Villages are naturally generating structures that form above ground.
    
    They are usually generated in desert, plains, taiga, and savanna biomes
    and are a site for villager spawns, with whom the player can trade.
    """
    NETHER_FORTRESS = register(StructureType("fortress", MapCursor.Type.RED_X))
    """
    Nether fortresses are very large complexes that mainly consist of
    netherbricks.
    
    They contain blaze spawners, nether wart farms, and loot chests. They are
    only generated in the nether dimension.
    """
    STRONGHOLD = register(StructureType("stronghold", MapCursor.Type.MANSION))
    """
    Strongholds are underground structures that consist of many rooms,
    libraries, and an end portal room.
    
    They can be found using an Material.ENDER_EYE.
    """
    JUNGLE_PYRAMID = register(StructureType("jungle_pyramid", MapCursor.Type.RED_X))
    """
    Jungle pyramids (also known as jungle temples) are found in jungles.
    
    They are usually composed of cobblestone and mossy cobblestone. They
    consist of three floors, with the bottom floor containing treasure
    chests.
    """
    OCEAN_RUIN = register(StructureType("ocean_ruin", MapCursor.Type.MONUMENT))
    """
    Ocean ruins are clusters of many different blocks that generate
    underwater in ocean biomes (as well as on the surface of beaches).
    
    They come in my different variations. The cold variants consist primarily
    of stone brick, and the warm variants consist of sandstone.
    """
    DESERT_PYRAMID = register(StructureType("desert_pyramid", MapCursor.Type.RED_X))
    """
    Desert pyramids (also known as desert temples) are found in deserts.
    
    They are usually composed of sandstone and stained terracotta.
    """
    IGLOO = register(StructureType("igloo", MapCursor.Type.RED_X))
    """
    Igloos are structures that generate in snowy biomes.
    
    They consist of the house, as well as a basement.
    """
    SWAMP_HUT = register(StructureType("swamp_hut", MapCursor.Type.RED_X))
    """
    Swamp huts (also known as witch huts) generate in swamp biomes and have
    the ability to spawn witches.
    """
    OCEAN_MONUMENT = register(StructureType("monument", MapCursor.Type.MONUMENT))
    """
    Ocean monuments are underwater structures.
    
    They are usually composed on all three different prismarine types and sea
    lanterns. They are the only place guardians and elder guardians spawn
    naturally.
    """
    END_CITY = register(StructureType("end_city", MapCursor.Type.RED_X))
    """
    End Cities are tall castle-like structures that generate in the outer
    island of the End dimension.
    
    They consist primarily of end stone bricks, purpur blocks, and end rods.
    They are the only place where shulkers can be found.
    """
    WOODLAND_MANSION = register(StructureType("mansion", MapCursor.Type.MANSION))
    """
    Mansions (also known as woodland mansions) are massive house structures
    that generate in dark forests, containing a wide variety of rooms.
    
    They are the only place where evokers, vindicators, and vexes spawn
    naturally (but only once)
    """
    BURIED_TREASURE = register(StructureType("buried_treasure", MapCursor.Type.RED_X))
    """
    Buried treasure consists of a single chest buried in the beach sand or
    gravel, with random loot in it.
    """
    SHIPWRECK = register(StructureType("shipwreck", MapCursor.Type.RED_X))
    """
    Shipwrecks are structures that generate on the floor of oceans or
    beaches.
    
    They are made up of wood materials, and contain 1-3 loot chests. They can
    generate sideways, upside-down, or upright.
    """
    PILLAGER_OUTPOST = register(StructureType("pillager_outpost", MapCursor.Type.RED_X))
    """
    Pillager outposts may contain crossbows.
    """
    NETHER_FOSSIL = register(StructureType("nether_fossil", MapCursor.Type.RED_X))
    """
    Nether fossils.
    """
    RUINED_PORTAL = register(StructureType("ruined_portal", MapCursor.Type.RED_X))
    """
    Ruined portal.
    """
    BASTION_REMNANT = register(StructureType("bastion_remnant", MapCursor.Type.RED_X))
    """
    Bastion remnant.
    """


    def getName(self) -> str:
        """
        Get the name of this structure. This is case-sensitive when used in
        commands.

        Returns
        - the name of this structure
        """
        ...


    def getMapIcon(self) -> "MapCursor.Type":
        """
        Get the org.bukkit.map.MapCursor.Type that this structure can use on maps. If
        this is null, this structure will not appear on explorer maps.

        Returns
        - the org.bukkit.map.MapCursor.Type or null.
        """
        ...


    def equals(self, other: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        ...


    @staticmethod
    def getStructureTypes() -> dict[str, "StructureType"]:
        """
        Get all registered StructureTypes.

        Returns
        - an immutable copy of registered structure types.
        """
        ...


    def getKey(self) -> "NamespacedKey":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Jigsaw

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import BlockData
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Jigsaw(BlockData):
    """
    'orientation' is the direction the block is facing.
    """

    def getOrientation(self) -> "Orientation":
        """
        Gets the value of the 'orientation' property.

        Returns
        - the 'orientation' value
        """
        ...


    def setOrientation(self, orientation: "Orientation") -> None:
        """
        Sets the value of the 'orientation' property.

        Arguments
        - orientation: the new 'orientation' value
        """
        ...


    class Orientation(Enum):
        """
        The directions the Jigsaw can be oriented.
        """

        DOWN_EAST = 0
        DOWN_NORTH = 1
        DOWN_SOUTH = 2
        DOWN_WEST = 3
        UP_EAST = 4
        UP_NORTH = 5
        UP_SOUTH = 6
        UP_WEST = 7
        WEST_UP = 8
        EAST_UP = 9
        NORTH_UP = 10
        SOUTH_UP = 11



"""
Python module generated from Java source file org.bukkit.event.block.BlockPistonExtendEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Collections
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockPistonExtendEvent(BlockPistonEvent):
    """
    Called when a piston extends
    """

    def __init__(self, block: "Block", length: int, direction: "BlockFace"):
        ...


    def __init__(self, block: "Block", blocks: list["Block"], direction: "BlockFace"):
        ...


    def getLength(self) -> int:
        """
        Get the amount of blocks which will be moved while extending.

        Returns
        - the amount of moving blocks

        Deprecated
        - slime blocks make the value of this method
                 inaccurate due to blocks being pushed at the side
        """
        ...


    def getBlocks(self) -> list["Block"]:
        """
        Get an immutable list of the blocks which will be moved by the
        extending.

        Returns
        - Immutable list of the moved blocks.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.Orientable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Axis
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class Orientable(BlockData):
    """
    'axis' represents the axis along whilst this block is oriented.
    
    Some blocks such as the portal block may not be able to be placed in all
    orientations, use .getAxes() to retrieve all possible such
    orientations.
    """

    def getAxis(self) -> "Axis":
        """
        Gets the value of the 'axis' property.

        Returns
        - the 'axis' value
        """
        ...


    def setAxis(self, axis: "Axis") -> None:
        """
        Sets the value of the 'axis' property.

        Arguments
        - axis: the new 'axis' value
        """
        ...


    def getAxes(self) -> set["Axis"]:
        """
        Gets the axes which are applicable to this block.

        Returns
        - the allowed 'axis' values
        """
        ...



"""
Python module generated from Java source file java.text.DecimalFormat

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.math import BigDecimal
from java.math import BigInteger
from java.math import RoundingMode
from java.text import *
from java.text.spi import NumberFormatProvider
from java.util import Currency
from java.util import Locale
from java.util.concurrent.atomic import AtomicInteger
from java.util.concurrent.atomic import AtomicLong
from sun.util.locale.provider import LocaleProviderAdapter
from sun.util.locale.provider import ResourceBundleBasedAdapter
from typing import Any, Callable, Iterable, Tuple


class DecimalFormat(NumberFormat):
    """
    `DecimalFormat` is a concrete subclass of
    `NumberFormat` that formats decimal numbers. It has a variety of
    features designed to make it possible to parse and format numbers in any
    locale, including support for Western, Arabic, and Indic digits.  It also
    supports different kinds of numbers, including integers (123), fixed-point
    numbers (123.4), scientific notation (1.23E4), percentages (12%), and
    currency amounts ($123).  All of these can be localized.
    
    To obtain a `NumberFormat` for a specific locale, including the
    default locale, call one of `NumberFormat`'s factory methods, such
    as `getInstance()`.  In general, do not call the
    `DecimalFormat` constructors directly, since the
    `NumberFormat` factory methods may return subclasses other than
    `DecimalFormat`. If you need to customize the format object, do
    something like this:
    
    <blockquote>```
    NumberFormat f = NumberFormat.getInstance(loc);
    if (f instanceof DecimalFormat) {
        ((DecimalFormat) f).setDecimalSeparatorAlwaysShown(True);
    }
    ```</blockquote>
    
    A `DecimalFormat` comprises a *pattern* and a set of
    *symbols*.  The pattern may be set directly using
    `applyPattern()`, or indirectly using the API methods.  The
    symbols are stored in a `DecimalFormatSymbols` object.  When using
    the `NumberFormat` factory methods, the pattern and symbols are
    read from localized `ResourceBundle`s.
    
    <h2>Patterns</h2>
    
    `DecimalFormat` patterns have the following syntax:
    <blockquote>```
    *Pattern:*
            *PositivePattern*
            *PositivePattern* ; *NegativePattern*
    *PositivePattern:*
            *Prefix<sub>opt</sub>* *Number* *Suffix<sub>opt</sub>*
    *NegativePattern:*
            *Prefix<sub>opt</sub>* *Number* *Suffix<sub>opt</sub>*
    *Prefix:*
            any Unicode characters except &#92;uFFFE, &#92;uFFFF, and special characters
    *Suffix:*
            any Unicode characters except &#92;uFFFE, &#92;uFFFF, and special characters
    *Number:*
            *Integer* *Exponent<sub>opt</sub>*
            *Integer* . *Fraction* *Exponent<sub>opt</sub>*
    *Integer:*
            *MinimumInteger*
            #
            # *Integer*
            # , *Integer*
    *MinimumInteger:*
            0
            0 *MinimumInteger*
            0 , *MinimumInteger*
    *Fraction:*
            *MinimumFraction<sub>opt</sub>* *OptionalFraction<sub>opt</sub>*
    *MinimumFraction:*
            0 *MinimumFraction<sub>opt</sub>*
    *OptionalFraction:*
            # *OptionalFraction<sub>opt</sub>*
    *Exponent:*
            E *MinimumExponent*
    *MinimumExponent:*
            0 *MinimumExponent<sub>opt</sub>*
    ```</blockquote>
    
    A `DecimalFormat` pattern contains a positive and negative
    subpattern, for example, `".,..0.00;(.,..0.00)"`.  Each
    subpattern has a prefix, numeric part, and suffix. The negative subpattern
    is optional; if absent, then the positive subpattern prefixed with the
    minus sign (`'-' U+002D HYPHEN-MINUS`) is used as the
    negative subpattern. That is, `"0.00"` alone is equivalent to
    `"0.00;-0.00"`.  If there is an explicit negative subpattern, it
    serves only to specify the negative prefix and suffix; the number of digits,
    minimal digits, and other characteristics are all the same as the positive
    pattern. That means that `".,..0.0.;(.)"` produces precisely
    the same behavior as `".,..0.0.;(.,..0.0.)"`.
    
    The prefixes, suffixes, and various symbols used for infinity, digits,
    grouping separators, decimal separators, etc. may be set to arbitrary
    values, and they will appear properly during formatting.  However, care must
    be taken that the symbols and strings do not conflict, or parsing will be
    unreliable.  For example, either the positive and negative prefixes or the
    suffixes must be distinct for `DecimalFormat.parse()` to be able
    to distinguish positive from negative values.  (If they are identical, then
    `DecimalFormat` will behave as if no negative subpattern was
    specified.)  Another example is that the decimal separator and grouping
    separator should be distinct characters, or parsing will be impossible.
    
    The grouping separator is commonly used for thousands, but in some
    countries it separates ten-thousands. The grouping size is a constant number
    of digits between the grouping characters, such as 3 for 100,000,000 or 4 for
    1,0000,0000.  If you supply a pattern with multiple grouping characters, the
    interval between the last one and the end of the integer is the one that is
    used. So `".,..,...,...."` == `"......,...."` ==
    `"..,....,...."`.
    
    <h3><a id="special_pattern_character">Special Pattern Characters</a></h3>
    
    Many characters in a pattern are taken literally; they are matched during
    parsing and output unchanged during formatting.  Special characters, on the
    other hand, stand for other characters, strings, or classes of characters.
    They must be quoted, unless noted otherwise, if they are to appear in the
    prefix or suffix as literals.
    
    The characters listed here are used in non-localized patterns.  Localized
    patterns use the corresponding characters taken from this formatter's
    `DecimalFormatSymbols` object instead, and these characters lose
    their special status.  Two exceptions are the currency sign and quote, which
    are not localized.
    
    <blockquote>
    <table class="striped">
    <caption style="display:none">Chart showing symbol, location, localized, and meaning.</caption>
    <thead>
        <tr>
             <th scope="col" style="text-align:left">Symbol
             <th scope="col" style="text-align:left">Location
             <th scope="col" style="text-align:left">Localized?
             <th scope="col" style="text-align:left">Meaning
    </thead>
    <tbody>
        <tr style="vertical-align:top">
             <th scope="row">`0`
             <td>Number
             <td>Yes
             <td>Digit
        <tr style="vertical-align: top">
             <th scope="row">`.`
             <td>Number
             <td>Yes
             <td>Digit, zero shows as absent
        <tr style="vertical-align:top">
             <th scope="row">`.`
             <td>Number
             <td>Yes
             <td>Decimal separator or monetary decimal separator
        <tr style="vertical-align: top">
             <th scope="row">`-`
             <td>Number
             <td>Yes
             <td>Minus sign
        <tr style="vertical-align:top">
             <th scope="row">`,`
             <td>Number
             <td>Yes
             <td>Grouping separator or monetary grouping separator
        <tr style="vertical-align: top">
             <th scope="row">`E`
             <td>Number
             <td>Yes
             <td>Separates mantissa and exponent in scientific notation.
                 *Need not be quoted in prefix or suffix.*
        <tr style="vertical-align:top">
             <th scope="row">`;`
             <td>Subpattern boundary
             <td>Yes
             <td>Separates positive and negative subpatterns
        <tr style="vertical-align: top">
             <th scope="row">`%`
             <td>Prefix or suffix
             <td>Yes
             <td>Multiply by 100 and show as percentage
        <tr style="vertical-align:top">
             <th scope="row">`&.92;u2030`
             <td>Prefix or suffix
             <td>Yes
             <td>Multiply by 1000 and show as per mille value
        <tr style="vertical-align: top">
             <th scope="row">`&.164;` (`&.92;u00A4`)
             <td>Prefix or suffix
             <td>No
             <td>Currency sign, replaced by currency symbol.  If
                 doubled, replaced by international currency symbol.
                 If present in a pattern, the monetary decimal/grouping separators
                 are used instead of the decimal/grouping separators.
        <tr style="vertical-align:top">
             <th scope="row">`'`
             <td>Prefix or suffix
             <td>No
             <td>Used to quote special characters in a prefix or suffix,
                 for example, `"'.'."` formats 123 to
                 `".123"`.  To create a single quote
                 itself, use two in a row: `". o''clock"`.
    </tbody>
    </table>
    </blockquote>
    
    <h3>Scientific Notation</h3>
    
    Numbers in scientific notation are expressed as the product of a mantissa
    and a power of ten, for example, 1234 can be expressed as 1.234 x 10^3.  The
    mantissa is often in the range 1.0 &le; x < 10.0, but it need not
    be.
    `DecimalFormat` can be instructed to format and parse scientific
    notation *only via a pattern*; there is currently no factory method
    that creates a scientific notation format.  In a pattern, the exponent
    character immediately followed by one or more digit characters indicates
    scientific notation.  Example: `"0....E0"` formats the number
    1234 as `"1.234E3"`.
    
    
    - The number of digit characters after the exponent character gives the
    minimum exponent digit count.  There is no maximum.  Negative exponents are
    formatted using the localized minus sign, *not* the prefix and suffix
    from the pattern.  This allows patterns such as `"0....E0 m/s"`.
    
    - The minimum and maximum number of integer digits are interpreted
    together:
    
    
    - If the maximum number of integer digits is greater than their minimum number
    and greater than 1, it forces the exponent to be a multiple of the maximum
    number of integer digits, and the minimum number of integer digits to be
    interpreted as 1.  The most common use of this is to generate
    *engineering notation*, in which the exponent is a multiple of three,
    e.g., `"..0......E0"`. Using this pattern, the number 12345
    formats to `"12.345E3"`, and 123456 formats to
    `"123.456E3"`.
    
    - Otherwise, the minimum number of integer digits is achieved by adjusting the
    exponent.  Example: 0.00123 formatted with `"00....E0"` yields
    `"12.3E-4"`.
    
    
    - The number of significant digits in the mantissa is the sum of the
    *minimum integer* and *maximum fraction* digits, and is
    unaffected by the maximum integer digits.  For example, 12345 formatted with
    `"..0...E0"` is `"12.3E3"`. To show all digits, set
    the significant digits count to zero.  The number of significant digits
    does not affect parsing.
    
    - Exponential patterns may not contain grouping separators.
    
    
    <h3>Rounding</h3>
    
    `DecimalFormat` provides rounding modes defined in
    java.math.RoundingMode for formatting.  By default, it uses
    java.math.RoundingMode.HALF_EVEN RoundingMode.HALF_EVEN.
    
    <h3>Digits</h3>
    
    For formatting, `DecimalFormat` uses the ten consecutive
    characters starting with the localized zero digit defined in the
    `DecimalFormatSymbols` object as digits. For parsing, these
    digits as well as all Unicode decimal digits, as defined by
    Character.digit Character.digit, are recognized.
    
    <h4>Special Values</h4>
    
    `NaN` is formatted as a string, which typically has a single character
    `&.92;uFFFD`.  This string is determined by the
    `DecimalFormatSymbols` object.  This is the only value for which
    the prefixes and suffixes are not used.
    
    Infinity is formatted as a string, which typically has a single character
    `&.92;u221E`, with the positive or negative prefixes and suffixes
    applied.  The infinity string is determined by the
    `DecimalFormatSymbols` object.
    
    Negative zero (`"-0"`) parses to
    
    - `BigDecimal(0)` if `isParseBigDecimal()` is
    True,
    - `Long(0)` if `isParseBigDecimal()` is False
        and `isParseIntegerOnly()` is True,
    - `Double(-0.0)` if both `isParseBigDecimal()`
    and `isParseIntegerOnly()` are False.
    
    
    <h3><a id="synchronization">Synchronization</a></h3>
    
    
    Decimal formats are generally not synchronized.
    It is recommended to create separate format instances for each thread.
    If multiple threads access a format concurrently, it must be synchronized
    externally.
    
    <h3>Example</h3>
    
    <blockquote>```<strong>`// Print out a number using the localized number, integer, currency,
    // and percent format for each locale`</strong>`Locale[] locales = NumberFormat.getAvailableLocales();
    double myNumber = -1234.56;
    NumberFormat form;
    for (int j = 0; j < 4; ++j) {
        System.out.println("FORMAT");
        for (int i = 0; i < locales.length; ++i) {
            if (locales[i].getCountry().length() == 0) {
               continue; // Skip language-only locales`
            System.out.print(locales[i].getDisplayName());
            switch (j) {
            case 0:
                form = NumberFormat.getInstance(locales[i]); break;
            case 1:
                form = NumberFormat.getIntegerInstance(locales[i]); break;
            case 2:
                form = NumberFormat.getCurrencyInstance(locales[i]); break;
            default:
                form = NumberFormat.getPercentInstance(locales[i]); break;
            }
            if (form instanceof DecimalFormat) {
                System.out.print(": " + ((DecimalFormat) form).toPattern());
            }
            System.out.print(" -> " + form.format(myNumber));
            try {
                System.out.println(" -> " + form.parse(form.format(myNumber)));
            } catch (ParseException e) {}
        }
    }
    }```</blockquote>

    Author(s)
    - Alan Liu

    See
    - ParsePosition

    Since
    - 1.1
    """

    def __init__(self):
        """
        Creates a DecimalFormat using the default pattern and symbols
        for the default java.util.Locale.Category.FORMAT FORMAT locale.
        This is a convenient way to obtain a
        DecimalFormat when internationalization is not the main concern.
        
        To obtain standard formats for a given locale, use the factory methods
        on NumberFormat such as getNumberInstance. These factories will
        return the most appropriate sub-class of NumberFormat for a given
        locale.

        See
        - java.text.NumberFormat.getPercentInstance
        """
        ...


    def __init__(self, pattern: str):
        """
        Creates a DecimalFormat using the given pattern and the symbols
        for the default java.util.Locale.Category.FORMAT FORMAT locale.
        This is a convenient way to obtain a
        DecimalFormat when internationalization is not the main concern.
        
        To obtain standard formats for a given locale, use the factory methods
        on NumberFormat such as getNumberInstance. These factories will
        return the most appropriate sub-class of NumberFormat for a given
        locale.

        Arguments
        - pattern: a non-localized pattern string.

        Raises
        - NullPointerException: if `pattern` is null
        - IllegalArgumentException: if the given pattern is invalid.

        See
        - java.text.NumberFormat.getPercentInstance
        """
        ...


    def __init__(self, pattern: str, symbols: "DecimalFormatSymbols"):
        """
        Creates a DecimalFormat using the given pattern and symbols.
        Use this constructor when you need to completely customize the
        behavior of the format.
        
        To obtain standard formats for a given
        locale, use the factory methods on NumberFormat such as
        getInstance or getCurrencyInstance. If you need only minor adjustments
        to a standard format, you can modify the format returned by
        a NumberFormat factory method.

        Arguments
        - pattern: a non-localized pattern string
        - symbols: the set of symbols to be used

        Raises
        - NullPointerException: if any of the given arguments is null
        - IllegalArgumentException: if the given pattern is invalid

        See
        - java.text.DecimalFormatSymbols
        """
        ...


    def format(self, number: "Object", toAppendTo: "StringBuffer", pos: "FieldPosition") -> "StringBuffer":
        """
        Formats a number and appends the resulting text to the given string
        buffer.
        The number can be of any subclass of java.lang.Number.
        
        This implementation uses the maximum precision permitted.

        Arguments
        - number: the number to format
        - toAppendTo: the `StringBuffer` to which the formatted
                          text is to be appended
        - pos: keeps track on the position of the field within the
                          returned string. For example, for formatting a number
                          `1234567.89` in `Locale.US` locale,
                          if the given `fieldPosition` is
                          NumberFormat.INTEGER_FIELD, the begin index
                          and end index of `fieldPosition` will be set
                          to 0 and 9, respectively for the output string
                          `1,234,567.89`.

        Returns
        - the value passed in as `toAppendTo`

        Raises
        - IllegalArgumentException: if `number` is
                          null or not an instance of `Number`.
        - NullPointerException: if `toAppendTo` or
                          `pos` is null
        - ArithmeticException: if rounding is needed with rounding
                          mode being set to RoundingMode.UNNECESSARY

        See
        - java.text.FieldPosition
        """
        ...


    def format(self, number: float, result: "StringBuffer", fieldPosition: "FieldPosition") -> "StringBuffer":
        """
        Formats a double to produce a string.

        Arguments
        - number: The double to format
        - result: where the text is to be appended
        - fieldPosition: keeps track on the position of the field within
                                the returned string. For example, for formatting
                                a number `1234567.89` in `Locale.US`
                                locale, if the given `fieldPosition` is
                                NumberFormat.INTEGER_FIELD, the begin index
                                and end index of `fieldPosition` will be set
                                to 0 and 9, respectively for the output string
                                `1,234,567.89`.

        Returns
        - The formatted number string

        Raises
        - NullPointerException: if `result` or
                   `fieldPosition` is `null`
        - ArithmeticException: if rounding is needed with rounding
                   mode being set to RoundingMode.UNNECESSARY

        See
        - java.text.FieldPosition
        """
        ...


    def format(self, number: int, result: "StringBuffer", fieldPosition: "FieldPosition") -> "StringBuffer":
        """
        Format a long to produce a string.

        Arguments
        - number: The long to format
        - result: where the text is to be appended
        - fieldPosition: keeps track on the position of the field within
                                the returned string. For example, for formatting
                                a number `123456789` in `Locale.US`
                                locale, if the given `fieldPosition` is
                                NumberFormat.INTEGER_FIELD, the begin index
                                and end index of `fieldPosition` will be set
                                to 0 and 11, respectively for the output string
                                `123,456,789`.

        Returns
        - The formatted number string

        Raises
        - NullPointerException: if `result` or
                         `fieldPosition` is `null`
        - ArithmeticException: if rounding is needed with rounding
                         mode being set to RoundingMode.UNNECESSARY

        See
        - java.text.FieldPosition
        """
        ...


    def formatToCharacterIterator(self, obj: "Object") -> "AttributedCharacterIterator":
        """
        Formats an Object producing an `AttributedCharacterIterator`.
        You can use the returned `AttributedCharacterIterator`
        to build the resulting String, as well as to determine information
        about the resulting String.
        
        Each attribute key of the AttributedCharacterIterator will be of type
        `NumberFormat.Field`, with the attribute value being the
        same as the attribute key.

        Arguments
        - obj: The object to format

        Returns
        - AttributedCharacterIterator describing the formatted value.

        Raises
        - NullPointerException: if obj is null.
        - IllegalArgumentException: when the Format cannot format the
                   given object.
        - ArithmeticException: if rounding is needed with rounding
                          mode being set to RoundingMode.UNNECESSARY

        Since
        - 1.4
        """
        ...


    def parse(self, text: str, pos: "ParsePosition") -> "Number":
        """
        Parses text from a string to produce a `Number`.
        
        The method attempts to parse text starting at the index given by
        `pos`.
        If parsing succeeds, then the index of `pos` is updated
        to the index after the last character used (parsing does not necessarily
        use all characters up to the end of the string), and the parsed
        number is returned. The updated `pos` can be used to
        indicate the starting point for the next call to this method.
        If an error occurs, then the index of `pos` is not
        changed, the error index of `pos` is set to the index of
        the character where the error occurred, and null is returned.
        
        The subclass returned depends on the value of .isParseBigDecimal
        as well as on the string being parsed.
        
          - If `isParseBigDecimal()` is False (the default),
              most integer values are returned as `Long`
              objects, no matter how they are written: `"17"` and
              `"17.000"` both parse to `Long(17)`.
              Values that cannot fit into a `Long` are returned as
              `Double`s. This includes values with a fractional part,
              infinite values, `NaN`, and the value -0.0.
              `DecimalFormat` does *not* decide whether to
              return a `Double` or a `Long` based on the
              presence of a decimal separator in the source string. Doing so
              would prevent integers that overflow the mantissa of a double,
              such as `"-9,223,372,036,854,775,808.00"`, from being
              parsed accurately.
              
              Callers may use the `Number` methods
              `doubleValue`, `longValue`, etc., to obtain
              the type they want.
          - If `isParseBigDecimal()` is True, values are returned
              as `BigDecimal` objects. The values are the ones
              constructed by java.math.BigDecimal.BigDecimal(String)
              for corresponding strings in locale-independent format. The
              special cases negative and positive infinity and NaN are returned
              as `Double` instances holding the values of the
              corresponding `Double` constants.
        
        
        `DecimalFormat` parses all Unicode characters that represent
        decimal digits, as defined by `Character.digit()`. In
        addition, `DecimalFormat` also recognizes as digits the ten
        consecutive characters starting with the localized zero digit defined in
        the `DecimalFormatSymbols` object.

        Arguments
        - text: the string to be parsed
        - pos: A `ParsePosition` object with index and error
                    index information as described above.

        Returns
        - the parsed value, or `null` if the parse fails

        Raises
        - NullPointerException: if `text` or
                    `pos` is null.
        """
        ...


    def getDecimalFormatSymbols(self) -> "DecimalFormatSymbols":
        """
        Returns a copy of the decimal format symbols, which is generally not
        changed by the programmer or user.

        Returns
        - a copy of the desired DecimalFormatSymbols

        See
        - java.text.DecimalFormatSymbols
        """
        ...


    def setDecimalFormatSymbols(self, newSymbols: "DecimalFormatSymbols") -> None:
        """
        Sets the decimal format symbols, which is generally not changed
        by the programmer or user.

        Arguments
        - newSymbols: desired DecimalFormatSymbols

        See
        - java.text.DecimalFormatSymbols
        """
        ...


    def getPositivePrefix(self) -> str:
        """
        Get the positive prefix.
        <P>Examples: +123, $123, sFr123

        Returns
        - the positive prefix
        """
        ...


    def setPositivePrefix(self, newValue: str) -> None:
        """
        Set the positive prefix.
        <P>Examples: +123, $123, sFr123

        Arguments
        - newValue: the new positive prefix
        """
        ...


    def getNegativePrefix(self) -> str:
        """
        Get the negative prefix.
        <P>Examples: -123, ($123) (with negative suffix), sFr-123

        Returns
        - the negative prefix
        """
        ...


    def setNegativePrefix(self, newValue: str) -> None:
        """
        Set the negative prefix.
        <P>Examples: -123, ($123) (with negative suffix), sFr-123

        Arguments
        - newValue: the new negative prefix
        """
        ...


    def getPositiveSuffix(self) -> str:
        """
        Get the positive suffix.
        <P>Example: 123%

        Returns
        - the positive suffix
        """
        ...


    def setPositiveSuffix(self, newValue: str) -> None:
        """
        Set the positive suffix.
        <P>Example: 123%

        Arguments
        - newValue: the new positive suffix
        """
        ...


    def getNegativeSuffix(self) -> str:
        """
        Get the negative suffix.
        <P>Examples: -123%, ($123) (with positive suffixes)

        Returns
        - the negative suffix
        """
        ...


    def setNegativeSuffix(self, newValue: str) -> None:
        """
        Set the negative suffix.
        <P>Examples: 123%

        Arguments
        - newValue: the new negative suffix
        """
        ...


    def getMultiplier(self) -> int:
        """
        Gets the multiplier for use in percent, per mille, and similar
        formats.

        Returns
        - the multiplier

        See
        - .setMultiplier(int)
        """
        ...


    def setMultiplier(self, newValue: int) -> None:
        """
        Sets the multiplier for use in percent, per mille, and similar
        formats.
        For a percent format, set the multiplier to 100 and the suffixes to
        have '%' (for Arabic, use the Arabic percent sign).
        For a per mille format, set the multiplier to 1000 and the suffixes to
        have '&#92;u2030'.
        
        <P>Example: with multiplier 100, 1.23 is formatted as "123", and
        "123" is parsed into 1.23.

        Arguments
        - newValue: the new multiplier

        See
        - .getMultiplier
        """
        ...


    def setGroupingUsed(self, newValue: bool) -> None:
        """

        """
        ...


    def getGroupingSize(self) -> int:
        """
        Return the grouping size. Grouping size is the number of digits between
        grouping separators in the integer portion of a number.  For example,
        in the number "123,456.78", the grouping size is 3. Grouping size of
        zero designates that grouping is not used, which provides the same
        formatting as if calling .setGroupingUsed(boolean)
        setGroupingUsed(False).

        Returns
        - the grouping size

        See
        - java.text.DecimalFormatSymbols.getGroupingSeparator
        """
        ...


    def setGroupingSize(self, newValue: int) -> None:
        """
        Set the grouping size. Grouping size is the number of digits between
        grouping separators in the integer portion of a number.  For example,
        in the number "123,456.78", the grouping size is 3. Grouping size of
        zero designates that grouping is not used, which provides the same
        formatting as if calling .setGroupingUsed(boolean)
        setGroupingUsed(False).
        
        The value passed in is converted to a byte, which may lose information.
        Values that are negative or greater than
        java.lang.Byte.MAX_VALUE Byte.MAX_VALUE, will throw an
        `IllegalArgumentException`.

        Arguments
        - newValue: the new grouping size

        Raises
        - IllegalArgumentException: if `newValue` is negative or
                 greater than java.lang.Byte.MAX_VALUE Byte.MAX_VALUE

        See
        - java.text.DecimalFormatSymbols.setGroupingSeparator
        """
        ...


    def isDecimalSeparatorAlwaysShown(self) -> bool:
        """
        Allows you to get the behavior of the decimal separator with integers.
        (The decimal separator will always appear with decimals.)
        <P>Example: Decimal ON: 12345 &rarr; 12345.; OFF: 12345 &rarr; 12345

        Returns
        - `True` if the decimal separator is always shown;
                `False` otherwise
        """
        ...


    def setDecimalSeparatorAlwaysShown(self, newValue: bool) -> None:
        """
        Allows you to set the behavior of the decimal separator with integers.
        (The decimal separator will always appear with decimals.)
        <P>Example: Decimal ON: 12345 &rarr; 12345.; OFF: 12345 &rarr; 12345

        Arguments
        - newValue: `True` if the decimal separator is always shown;
                        `False` otherwise
        """
        ...


    def isParseBigDecimal(self) -> bool:
        """
        Returns whether the .parse(java.lang.String, java.text.ParsePosition)
        method returns `BigDecimal`. The default value is False.

        Returns
        - `True` if the parse method returns BigDecimal;
                `False` otherwise

        See
        - .setParseBigDecimal

        Since
        - 1.5
        """
        ...


    def setParseBigDecimal(self, newValue: bool) -> None:
        """
        Sets whether the .parse(java.lang.String, java.text.ParsePosition)
        method returns `BigDecimal`.

        Arguments
        - newValue: `True` if the parse method returns BigDecimal;
                        `False` otherwise

        See
        - .isParseBigDecimal

        Since
        - 1.5
        """
        ...


    def clone(self) -> "Object":
        """
        Standard override; no change in semantics.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Overrides equals
        """
        ...


    def hashCode(self) -> int:
        """
        Overrides hashCode
        """
        ...


    def toPattern(self) -> str:
        """
        Synthesizes a pattern string that represents the current state
        of this Format object.

        Returns
        - a pattern string

        See
        - .applyPattern
        """
        ...


    def toLocalizedPattern(self) -> str:
        """
        Synthesizes a localized pattern string that represents the current
        state of this Format object.

        Returns
        - a localized pattern string

        See
        - .applyPattern
        """
        ...


    def applyPattern(self, pattern: str) -> None:
        """
        Apply the given pattern to this Format object.  A pattern is a
        short-hand specification for the various formatting properties.
        These properties can also be changed individually through the
        various setter methods.
        
        There is no limit to integer digits set
        by this routine, since that is the typical end-user desire;
        use setMaximumInteger if you want to set a real value.
        For negative numbers, use a second pattern, separated by a semicolon
        <P>Example `".,.00.0."` &rarr; 1,234.56
        <P>This means a minimum of 2 integer digits, 1 fraction digit, and
        a maximum of 2 fraction digits.
        Example: `".,.00.0.;(.,.00.0.)"` for negatives in
        parentheses.
        In negative patterns, the minimum and maximum counts are ignored;
        these are presumed to be set in the positive pattern.

        Arguments
        - pattern: a new pattern

        Raises
        - NullPointerException: if `pattern` is null
        - IllegalArgumentException: if the given pattern is invalid.
        """
        ...


    def applyLocalizedPattern(self, pattern: str) -> None:
        """
        Apply the given pattern to this Format object.  The pattern
        is assumed to be in a localized notation. A pattern is a
        short-hand specification for the various formatting properties.
        These properties can also be changed individually through the
        various setter methods.
        
        There is no limit to integer digits set
        by this routine, since that is the typical end-user desire;
        use setMaximumInteger if you want to set a real value.
        For negative numbers, use a second pattern, separated by a semicolon
        <P>Example `".,.00.0."` &rarr; 1,234.56
        <P>This means a minimum of 2 integer digits, 1 fraction digit, and
        a maximum of 2 fraction digits.
        Example: `".,.00.0.;(.,.00.0.)"` for negatives in
        parentheses.
        In negative patterns, the minimum and maximum counts are ignored;
        these are presumed to be set in the positive pattern.

        Arguments
        - pattern: a new pattern

        Raises
        - NullPointerException: if `pattern` is null
        - IllegalArgumentException: if the given pattern is invalid.
        """
        ...


    def setMaximumIntegerDigits(self, newValue: int) -> None:
        """
        Sets the maximum number of digits allowed in the integer portion of a
        number.
        For formatting numbers other than `BigInteger` and
        `BigDecimal` objects, the lower of `newValue` and
        309 is used. Negative input values are replaced with 0.

        See
        - NumberFormat.setMaximumIntegerDigits
        """
        ...


    def setMinimumIntegerDigits(self, newValue: int) -> None:
        """
        Sets the minimum number of digits allowed in the integer portion of a
        number.
        For formatting numbers other than `BigInteger` and
        `BigDecimal` objects, the lower of `newValue` and
        309 is used. Negative input values are replaced with 0.

        See
        - NumberFormat.setMinimumIntegerDigits
        """
        ...


    def setMaximumFractionDigits(self, newValue: int) -> None:
        """
        Sets the maximum number of digits allowed in the fraction portion of a
        number.
        For formatting numbers other than `BigInteger` and
        `BigDecimal` objects, the lower of `newValue` and
        340 is used. Negative input values are replaced with 0.

        See
        - NumberFormat.setMaximumFractionDigits
        """
        ...


    def setMinimumFractionDigits(self, newValue: int) -> None:
        """
        Sets the minimum number of digits allowed in the fraction portion of a
        number.
        For formatting numbers other than `BigInteger` and
        `BigDecimal` objects, the lower of `newValue` and
        340 is used. Negative input values are replaced with 0.

        See
        - NumberFormat.setMinimumFractionDigits
        """
        ...


    def getMaximumIntegerDigits(self) -> int:
        """
        Gets the maximum number of digits allowed in the integer portion of a
        number.
        For formatting numbers other than `BigInteger` and
        `BigDecimal` objects, the lower of the return value and
        309 is used.

        See
        - .setMaximumIntegerDigits
        """
        ...


    def getMinimumIntegerDigits(self) -> int:
        """
        Gets the minimum number of digits allowed in the integer portion of a
        number.
        For formatting numbers other than `BigInteger` and
        `BigDecimal` objects, the lower of the return value and
        309 is used.

        See
        - .setMinimumIntegerDigits
        """
        ...


    def getMaximumFractionDigits(self) -> int:
        """
        Gets the maximum number of digits allowed in the fraction portion of a
        number.
        For formatting numbers other than `BigInteger` and
        `BigDecimal` objects, the lower of the return value and
        340 is used.

        See
        - .setMaximumFractionDigits
        """
        ...


    def getMinimumFractionDigits(self) -> int:
        """
        Gets the minimum number of digits allowed in the fraction portion of a
        number.
        For formatting numbers other than `BigInteger` and
        `BigDecimal` objects, the lower of the return value and
        340 is used.

        See
        - .setMinimumFractionDigits
        """
        ...


    def getCurrency(self) -> "Currency":
        """
        Gets the currency used by this decimal format when formatting
        currency values.
        The currency is obtained by calling
        DecimalFormatSymbols.getCurrency DecimalFormatSymbols.getCurrency
        on this number format's symbols.

        Returns
        - the currency used by this decimal format, or `null`

        Since
        - 1.4
        """
        ...


    def setCurrency(self, currency: "Currency") -> None:
        """
        Sets the currency used by this number format when formatting
        currency values. This does not update the minimum or maximum
        number of fraction digits used by the number format.
        The currency is set by calling
        DecimalFormatSymbols.setCurrency DecimalFormatSymbols.setCurrency
        on this number format's symbols.

        Arguments
        - currency: the new currency to be used by this decimal format

        Raises
        - NullPointerException: if `currency` is null

        Since
        - 1.4
        """
        ...


    def getRoundingMode(self) -> "RoundingMode":
        """
        Gets the java.math.RoundingMode used in this DecimalFormat.

        Returns
        - The `RoundingMode` used for this DecimalFormat.

        See
        - .setRoundingMode(RoundingMode)

        Since
        - 1.6
        """
        ...


    def setRoundingMode(self, roundingMode: "RoundingMode") -> None:
        """
        Sets the java.math.RoundingMode used in this DecimalFormat.

        Arguments
        - roundingMode: The `RoundingMode` to be used

        Raises
        - NullPointerException: if `roundingMode` is null.

        See
        - .getRoundingMode()

        Since
        - 1.6
        """
        ...



"""
Python module generated from Java source file java.util.ConcurrentModificationException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class ConcurrentModificationException(RuntimeException):
    """
    This exception may be thrown by methods that have detected concurrent
    modification of an object when such modification is not permissible.
    
    For example, it is not generally permissible for one thread to modify a Collection
    while another thread is iterating over it.  In general, the results of the
    iteration are undefined under these circumstances.  Some Iterator
    implementations (including those of all the general purpose collection implementations
    provided by the JRE) may choose to throw this exception if this behavior is
    detected.  Iterators that do this are known as *fail-fast* iterators,
    as they fail quickly and cleanly, rather that risking arbitrary,
    non-deterministic behavior at an undetermined time in the future.
    
    Note that this exception does not always indicate that an object has
    been concurrently modified by a *different* thread.  If a single
    thread issues a sequence of method invocations that violates the
    contract of an object, the object may throw this exception.  For
    example, if a thread modifies a collection directly while it is
    iterating over the collection with a fail-fast iterator, the iterator
    will throw this exception.
    
    Note that fail-fast behavior cannot be guaranteed as it is, generally
    speaking, impossible to make any hard guarantees in the presence of
    unsynchronized concurrent modification.  Fail-fast operations
    throw `ConcurrentModificationException` on a best-effort basis.
    Therefore, it would be wrong to write a program that depended on this
    exception for its correctness: *`ConcurrentModificationException`
    should be used only to detect bugs.*

    Author(s)
    - Josh Bloch

    See
    - AbstractList

    Since
    - 1.2
    """

    def __init__(self):
        """
        Constructs a ConcurrentModificationException with no
        detail message.
        """
        ...


    def __init__(self, message: str):
        """
        Constructs a `ConcurrentModificationException` with the
        specified detail message.

        Arguments
        - message: the detail message pertaining to this exception.
        """
        ...


    def __init__(self, cause: "Throwable"):
        """
        Constructs a new exception with the specified cause and a detail
        message of `(cause==null ? null : cause.toString())` (which
        typically contains the class and detail message of `cause`.

        Arguments
        - cause: the cause (which is saved for later retrieval by the
                Throwable.getCause() method).  (A `null` value is
                permitted, and indicates that the cause is nonexistent or
                unknown.)

        Since
        - 1.7
        """
        ...


    def __init__(self, message: str, cause: "Throwable"):
        """
        Constructs a new exception with the specified detail message and
        cause.
        
        Note that the detail message associated with `cause` is
        *not* automatically incorporated in this exception's detail
        message.

        Arguments
        - message: the detail message (which is saved for later retrieval
                by the Throwable.getMessage() method).
        - cause: the cause (which is saved for later retrieval by the
                Throwable.getCause() method).  (A `null` value
                is permitted, and indicates that the cause is nonexistent or
                unknown.)

        Since
        - 1.7
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.DirectExecutor

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from enum import Enum
from java.util.concurrent import Executor
from typing import Any, Callable, Iterable, Tuple


class DirectExecutor(Enum):
    """
    An Executor that runs each task in the thread that invokes Executor.execute
    execute.
    """

    INSTANCE = 0


    def execute(self, command: "Runnable") -> None:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.collect.SortedMultisets

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.collect import *
from com.google.common.collect.Multiset import Entry
from com.google.j2objc.annotations import Weak
from java.util import Comparator
from java.util import Iterator
from java.util import NavigableSet
from java.util import NoSuchElementException
from java.util import SortedSet
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class SortedMultisets:
    """
    Provides static utility methods for creating and working with SortedMultiset instances.

    Author(s)
    - Louis Wasserman
    """





"""
Python module generated from Java source file org.bukkit.event.entity.EntityBreakDoorEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import Block
from org.bukkit.entity import Entity
from org.bukkit.entity import LivingEntity
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityBreakDoorEvent(EntityChangeBlockEvent):
    """
    Called when an Entity breaks a door
    
    Cancelling the event will cause the event to be delayed
    """

    def __init__(self, entity: "LivingEntity", targetBlock: "Block"):
        ...


    def getEntity(self) -> "LivingEntity":
        ...



"""
Python module generated from Java source file org.bukkit.configuration.serialization.ConfigurationSerialization

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.lang.reflect import Constructor
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Method
from java.lang.reflect import Modifier
from org.bukkit import Color
from org.bukkit import FireworkEffect
from org.bukkit import Location
from org.bukkit.attribute import AttributeModifier
from org.bukkit.block.banner import Pattern
from org.bukkit.block.spawner import SpawnRule
from org.bukkit.configuration import Configuration
from org.bukkit.configuration.serialization import *
from org.bukkit.inventory import ItemStack
from org.bukkit.potion import PotionEffect
from org.bukkit.util import BlockVector
from org.bukkit.util import BoundingBox
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class ConfigurationSerialization:
    """
    Utility class for storing and retrieving classes for Configuration.
    """

    SERIALIZED_TYPE_KEY = "=="


    def deserialize(self, args: dict[str, Any]) -> "ConfigurationSerializable":
        ...


    @staticmethod
    def deserializeObject(args: dict[str, Any], clazz: type["ConfigurationSerializable"]) -> "ConfigurationSerializable":
        """
        Attempts to deserialize the given arguments into a new instance of the
        given class.
        
        The class must implement ConfigurationSerializable, including
        the extra methods as specified in the javadoc of
        ConfigurationSerializable.
        
        If a new instance could not be made, an example being the class not
        fully implementing the interface, null will be returned.

        Arguments
        - args: Arguments for deserialization
        - clazz: Class to deserialize into

        Returns
        - New instance of the specified class
        """
        ...


    @staticmethod
    def deserializeObject(args: dict[str, Any]) -> "ConfigurationSerializable":
        """
        Attempts to deserialize the given arguments into a new instance of the
        given class.
        
        The class must implement ConfigurationSerializable, including
        the extra methods as specified in the javadoc of
        ConfigurationSerializable.
        
        If a new instance could not be made, an example being the class not
        fully implementing the interface, null will be returned.

        Arguments
        - args: Arguments for deserialization

        Returns
        - New instance of the specified class
        """
        ...


    @staticmethod
    def registerClass(clazz: type["ConfigurationSerializable"]) -> None:
        """
        Registers the given ConfigurationSerializable class by its
        alias

        Arguments
        - clazz: Class to register
        """
        ...


    @staticmethod
    def registerClass(clazz: type["ConfigurationSerializable"], alias: str) -> None:
        """
        Registers the given alias to the specified ConfigurationSerializable class

        Arguments
        - clazz: Class to register
        - alias: Alias to register as

        See
        - SerializableAs
        """
        ...


    @staticmethod
    def unregisterClass(alias: str) -> None:
        """
        Unregisters the specified alias to a ConfigurationSerializable

        Arguments
        - alias: Alias to unregister
        """
        ...


    @staticmethod
    def unregisterClass(clazz: type["ConfigurationSerializable"]) -> None:
        """
        Unregisters any aliases for the specified ConfigurationSerializable class

        Arguments
        - clazz: Class to unregister
        """
        ...


    @staticmethod
    def getClassByAlias(alias: str) -> type["ConfigurationSerializable"]:
        """
        Attempts to get a registered ConfigurationSerializable class by
        its alias

        Arguments
        - alias: Alias of the serializable

        Returns
        - Registered class, or null if not found
        """
        ...


    @staticmethod
    def getAlias(clazz: type["ConfigurationSerializable"]) -> str:
        """
        Gets the correct alias for the given ConfigurationSerializable
        class

        Arguments
        - clazz: Class to get alias for

        Returns
        - Alias to use for the class
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.AbstractSortedMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import WeakOuter
from java.util import Comparator
from java.util import Iterator
from java.util import NavigableSet
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractSortedMultiset(AbstractMultiset, SortedMultiset):
    """
    This class provides a skeletal implementation of the SortedMultiset interface.
    
    The .count and .size implementations all iterate across the set returned by
    Multiset.entrySet(), as do many methods acting on the set returned by .elementSet(). Override those methods for better performance.

    Author(s)
    - Louis Wasserman
    """

    def elementSet(self) -> "NavigableSet"["E"]:
        ...


    def comparator(self) -> "Comparator"["E"]:
        ...


    def firstEntry(self) -> "Entry"["E"]:
        ...


    def lastEntry(self) -> "Entry"["E"]:
        ...


    def pollFirstEntry(self) -> "Entry"["E"]:
        ...


    def pollLastEntry(self) -> "Entry"["E"]:
        ...


    def subMultiset(self, fromElement: "E", fromBoundType: "BoundType", toElement: "E", toBoundType: "BoundType") -> "SortedMultiset"["E"]:
        ...


    def descendingMultiset(self) -> "SortedMultiset"["E"]:
        ...



"""
Python module generated from Java source file com.google.common.io.ByteArrayDataOutput

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from java.io import DataOutput
from java.io import IOException
from typing import Any, Callable, Iterable, Tuple


class ByteArrayDataOutput(DataOutput):
    """
    An extension of `DataOutput` for writing to in-memory byte arrays; its methods offer
    identical functionality but do not throw IOException.

    Author(s)
    - Jayaprabhakar Kadarkarai

    Since
    - 1.0
    """

    def write(self, b: int) -> None:
        ...


    def write(self, b: list[int]) -> None:
        ...


    def write(self, b: list[int], off: int, len: int) -> None:
        ...


    def writeBoolean(self, v: bool) -> None:
        ...


    def writeByte(self, v: int) -> None:
        ...


    def writeShort(self, v: int) -> None:
        ...


    def writeChar(self, v: int) -> None:
        ...


    def writeInt(self, v: int) -> None:
        ...


    def writeLong(self, v: int) -> None:
        ...


    def writeFloat(self, v: float) -> None:
        ...


    def writeDouble(self, v: float) -> None:
        ...


    def writeChars(self, s: str) -> None:
        ...


    def writeUTF(self, s: str) -> None:
        ...


    def writeBytes(self, s: str) -> None:
        """
        Deprecated
        - This method is dangerous as it discards the high byte of every character. For
            UTF-8, use `write(s.getBytes(StandardCharsets.UTF_8))`.
        """
        ...


    def toByteArray(self) -> list[int]:
        """
        Returns the contents that have been written to this instance, as a byte array.
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.Atomics

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.util.concurrent import *
from java.util.concurrent.atomic import AtomicReference
from java.util.concurrent.atomic import AtomicReferenceArray
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Atomics:
    """
    Static utility methods pertaining to classes in the `java.util.concurrent.atomic` package.

    Author(s)
    - Kurt Alfred Kluever

    Since
    - 10.0
    """

    @staticmethod
    def newReference() -> "AtomicReference"["V"]:
        """
        Creates an `AtomicReference` instance with no initial value.

        Returns
        - a new `AtomicReference` with no initial value
        """
        ...


    @staticmethod
    def newReference(initialValue: "V") -> "AtomicReference"["V"]:
        """
        Creates an `AtomicReference` instance with the given initial value.

        Arguments
        - initialValue: the initial value

        Returns
        - a new `AtomicReference` with the given initial value
        """
        ...


    @staticmethod
    def newReferenceArray(length: int) -> "AtomicReferenceArray"["E"]:
        """
        Creates an `AtomicReferenceArray` instance of given length.

        Arguments
        - length: the length of the array

        Returns
        - a new `AtomicReferenceArray` with the given length
        """
        ...


    @staticmethod
    def newReferenceArray(array: list["E"]) -> "AtomicReferenceArray"["E"]:
        """
        Creates an `AtomicReferenceArray` instance with the same length as, and all elements
        copied from, the given array.

        Arguments
        - array: the array to copy elements from

        Returns
        - a new `AtomicReferenceArray` copied from the given array
        """
        ...



"""
Python module generated from Java source file net.md_5.bungee.api.chat.ComponentStyleBuilder

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from net.md_5.bungee.api import ChatColor
from net.md_5.bungee.api.chat import *
from typing import Any, Callable, Iterable, Tuple


class ComponentStyleBuilder:
    """
    
    ComponentStyleBuilder simplifies creating component styles by allowing the
    use of a chainable builder.
    
    ```
    ComponentStyle style = ComponentStyle.builder()
        .color(ChatColor.RED)
        .font("custom:font")
        .bold(True).italic(True).create();
    
    BaseComponent component = new ComponentBuilder("Hello world").style(style).create();
    // Or it can be used directly on a component
    TextComponent text = new TextComponent("Hello world");
    text.applyStyle(style);
    ```

    See
    - ComponentStyle.builder(ComponentStyle)
    """

    def color(self, color: "ChatColor") -> "ComponentStyleBuilder":
        """
        Set the style color.

        Arguments
        - color: the color to set, or null to use the default

        Returns
        - this ComponentStyleBuilder for chaining
        """
        ...


    def font(self, font: str) -> "ComponentStyleBuilder":
        """
        Set the style font.

        Arguments
        - font: the font key to set, or null to use the default

        Returns
        - this ComponentStyleBuilder for chaining
        """
        ...


    def bold(self, bold: "Boolean") -> "ComponentStyleBuilder":
        """
        Set the style's bold property.

        Arguments
        - bold: the bold value to set, or null to use the default

        Returns
        - this ComponentStyleBuilder for chaining
        """
        ...


    def italic(self, italic: "Boolean") -> "ComponentStyleBuilder":
        """
        Set the style's italic property.

        Arguments
        - italic: the italic value to set, or null to use the default

        Returns
        - this ComponentStyleBuilder for chaining
        """
        ...


    def underlined(self, underlined: "Boolean") -> "ComponentStyleBuilder":
        """
        Set the style's underlined property.

        Arguments
        - underlined: the underlined value to set, or null to use the default

        Returns
        - this ComponentStyleBuilder for chaining
        """
        ...


    def strikethrough(self, strikethrough: "Boolean") -> "ComponentStyleBuilder":
        """
        Set the style's strikethrough property.

        Arguments
        - strikethrough: the strikethrough value to set, or null to use the
        default

        Returns
        - this ComponentStyleBuilder for chaining
        """
        ...


    def obfuscated(self, obfuscated: "Boolean") -> "ComponentStyleBuilder":
        """
        Set the style's obfuscated property.

        Arguments
        - obfuscated: the obfuscated value to set, or null to use the default

        Returns
        - this ComponentStyleBuilder for chaining
        """
        ...


    def build(self) -> "ComponentStyle":
        """
        Build the ComponentStyle using the values set in this builder.

        Returns
        - the created ComponentStyle
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Evoker

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Evoker(Spellcaster):
    """
    Represents an Evoker "Illager".
    """

    def getCurrentSpell(self) -> "Spell":
        """
        Gets the Spell the Evoker is currently using.

        Returns
        - the current spell

        Deprecated
        - future versions of Minecraft have additional spell casting
        entities.
        """
        ...


    def setCurrentSpell(self, spell: "Spell") -> None:
        """
        Sets the Spell the Evoker is currently using.

        Arguments
        - spell: the spell the evoker should be using

        Deprecated
        - future versions of Minecraft have additional spell casting
        entities.
        """
        ...


    class Spell(Enum):
        """
        Represents the current spell the Evoker is using.

        Deprecated
        - future versions of Minecraft have additional spell casting
        entities.
        """

        NONE = 0
        """
        No spell is being evoked.
        """
        SUMMON = 1
        """
        The spell that summons Vexes.
        """
        FANGS = 2
        """
        The spell that summons Fangs.
        """
        WOLOLO = 3
        """
        The "wololo" spell.
        """
        DISAPPEAR = 4
        """
        The spell that makes the casting entity invisible.
        """
        BLINDNESS = 5
        """
        The spell that makes the target blind.
        """
